<?php
/**
 * Register metabox for posts based on Redux Framework. Supported methods:
 *     isset_args( $post_type )
 *     set_args( $post_type, $redux_args, $metabox_args )
 *     add_section( $post_type, $sections )
 * Each post type can contains only one metabox. Pease note that each field id
 * leads by an underscore sign ( _ ) in order to not show that into Custom Field
 * Metabox from WordPress core feature.
 *
 * @param  CMS_Post_Metabox $metabox
 */

add_action( 'cms_post_metabox_register', 'medcaline_page_options_register' );

function medcaline_page_options_register( $metabox ) {

    if (class_exists('WPCF7')) {
        $cf7 = get_posts('post_type="wpcf7_contact_form"&numberposts=-1');

        $contact_forms = array();
        if ($cf7) {
            foreach ($cf7 as $cform) {
                $contact_forms[$cform->post_name] = $cform->post_title;
            }
        } else {
            $contact_forms[esc_html__('No contact forms found', 'medcaline')] = 0;
        }
    } else {
        $contact_forms = '';
    }

	if ( ! $metabox->isset_args( 'post' ) ) {
		$metabox->set_args( 'post', array(
			'opt_name'            => 'post_option',
			'display_name'        => esc_html__( 'Post Settings', 'medcaline' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'product' ) ) {
		$metabox->set_args( 'product', array(
			'opt_name'            => 'product_option',
			'display_name'        => esc_html__( 'Product Settings', 'medcaline' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'page' ) ) {
		$metabox->set_args( 'page', array(
			'opt_name'            => medcaline_get_page_opt_name(),
			'display_name'        => esc_html__( 'Page Settings', 'medcaline' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

    /* Extra Post Type */
    if ( ! $metabox->isset_args( 'case-study' ) ) {
        $metabox->set_args( 'case-study', array(
            'opt_name'            => 'portfolio_option',
            'display_name'        => esc_html__( 'Case Study Settings', 'medcaline' ),
            'show_options_object' => false,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }

    if ( ! $metabox->isset_args( 'service' ) ) {
        $metabox->set_args( 'service', array(
            'opt_name'            => 'service_option',
            'display_name'        => esc_html__( 'Service Settings', 'medcaline' ),
            'show_options_object' => false,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }

    if ( ! $metabox->isset_args( 'lq-team' ) ) {
        $metabox->set_args( 'lq-team', array(
            'opt_name'            => 'lq_team_option',
            'display_name'        => esc_html__( 'Psychologist Settings', 'medcaline' ),
            'show_options_object' => false,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }

	/**
	 * Config post meta options
	 *
	 */
	$metabox->add_section( 'post', array(
		'title'  => esc_html__( 'Post Settings', 'medcaline' ),
		'icon'   => 'el el-refresh',
		'fields' => array(
            array(
                'id'          => 'featured-video-url',
                'type'        => 'text',
                'title'       => esc_html__( 'Video URL', 'medcaline' ),
                'description' => esc_html__( 'Video will show when set post format is video', 'medcaline' ),
                'validate'    => 'url',
                'msg'         => 'Url error!',
            ),
            array(
                'id'=>'featured-quote-text',
                'type' => 'textarea',
                'title' => esc_html__('Quote Text', 'medcaline'),
                'default' => '',
            ),
            array(
                'id'          => 'featured-quote-cite',
                'type'        => 'text',
                'title'       => esc_html__( 'Quote Cite', 'medcaline' ),
                'description' => esc_html__( 'Quote will show when set post format is quote', 'medcaline' ),
            ),
            array(
                'id'          => 'featured-audio-url',
                'type'        => 'text',
                'title'       => esc_html__( 'Audio URL', 'medcaline' ),
                'description' => esc_html__( 'Audio that will show when set post format is audio', 'medcaline' ),
                'validate'    => 'url',
                'msg'         => 'Url error!',
            ),
            array(
                'id'       => 'featured-link-url',
                'type'     => 'text',
                'title'    => esc_html__( 'Link URL', 'medcaline' ),
                'validate' => 'url',
                'msg'      => 'Url error!'
            ),
            array(
                'id'          => 'featured-link-text',
                'type'        => 'text',
                'title'       => esc_html__( 'Link Text', 'medcaline' ),
            ),
            array(
                'id'          => 'featured-link-short',
                'type'        => 'text',
                'title'       => esc_html__( 'Link Short Text', 'medcaline' ),
                'description' => esc_html__( 'Link will show when set post format is link', 'medcaline' ),
            ),
			array(
				'id'             => 'post_content_padding',
				'type'           => 'spacing',
				'output'         => array( '.single-post #content' ),
				'right'          => false,
				'left'           => false,
				'mode'           => 'padding',
				'units'          => array( 'px' ),
				'units_extended' => 'false',
				'title'          => esc_html__( 'Content Padding', 'medcaline' ),
				'subtitle'     => esc_html__( 'Content site paddings.', 'medcaline' ),
				'desc'           => esc_html__( 'Default: Theme Option.', 'medcaline' ),
				'default'        => array(
					'padding-top'    => '',
					'padding-bottom' => '',
					'units'          => 'px',
				)
			),
		)
	) );

	/**
	 * Config page meta options
	 *
	 */
	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Header', 'medcaline' ),
		'desc'   => esc_html__( 'Header settings for the page.', 'medcaline' ),
		'icon'   => 'el-icon-website',
		'fields' => array(
			array(
				'id'      => 'custom_header',
				'type'    => 'switch',
				'title'   => esc_html__( 'Custom Header', 'medcaline' ),
				'default' => false,
				'indent'  => true
			),
			array(
				'id'           => 'header_layout',
				'type'         => 'image_select',
				'title'        => esc_html__( 'Layout', 'medcaline' ),
				'subtitle'     => esc_html__( 'Select a layout for header.', 'medcaline' ),
				'options'      => array(
					'0' => get_template_directory_uri() . '/assets/images/header-layout/h0.jpg',
					'1' => get_template_directory_uri() . '/assets/images/header-layout/h1.jpg',
					'2' => get_template_directory_uri() . '/assets/images/header-layout/h2.jpg',
                    '3' => get_template_directory_uri() . '/assets/images/header-layout/h3.jpg',
                    '4' => get_template_directory_uri() . '/assets/images/header-layout/h4.jpg',
				),
				'default'      => medcaline_get_option_of_theme_options( 'header_layout' ),
				'required'     => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
				'force_output' => true
			),
			array(
	            'id'       => 'logo_dark',
	            'type'     => 'media',
	            'title'    => esc_html__('Logo Dark', 'medcaline'),
	            'default' => '',
	            'required'     => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
				'force_output' => true
	        ),
		)
	) );

    $metabox->add_section( 'page', array(
        'title'  => esc_html__( 'Page Title', 'medcaline' ),
        'icon'   => 'el el-indent-left',
        'fields' => array(
            array(
                'id'           => 'custom_pagetitle',
                'type'         => 'button_set',
                'title'        => esc_html__( 'Page Title', 'medcaline' ),
                'options'      => array(
                    'themeoption'  => esc_html__( 'Theme Option', 'medcaline' ),
                    'hide'  => esc_html__( 'Elementor Content', 'medcaline' ),
                ),
                'default'      => 'themeoption',
                'desc'           => esc_html__( 'Inherit from Theme Option or build-in Elementor Content', 'medcaline' ),
            ),
            array(
                'id'       => 'page_ptitle_bg',
                'type'     => 'background',
                'title'    => esc_html__('Background', 'medcaline'),
                'subtitle' => esc_html__('Page title background.', 'medcaline'),
                'output'   => array('body.page #pagetitle.pagetitle'),
                'required' => array( 0 => 'custom_pagetitle', 1 => 'equals', 2 => 'themeoption' ),
                'force_output' => true,
                'transparent' => false,
                'background-color'     => false,
            ),
            array(
                'id'             => 'page_ptitle_padding',
                'type'           => 'spacing',
                'output'         => array('body #pagetitle.pagetitle'),
                'right'   => false,
                'left'    => false,
                'mode'           => 'padding',
                'units'          => array('px'),
                'units_extended' => 'false',
                'title'          => esc_html__('Page Title Padding', 'medcaline'),
                'default'            => array(
                    'padding-top'   => '',
                    'padding-bottom'   => '',
                    'units'          => 'px',
                ),
                'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'themeoption' ),
                'force_output' => true
            ),
            array(
                'id'      => 'page_breadcrumb_on',
                'type'    => 'switch',
                'title'   => esc_html__( 'Breadcrumb', 'medcaline' ),
                'default' => false,
                'required' => array( 0 => 'custom_pagetitle', 1 => 'equals', 2 => 'themeoption' ),
            ),
        )
    ) );

	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Content', 'medcaline' ),
		'desc'   => esc_html__( 'Settings for content area.', 'medcaline' ),
		'icon'   => 'el-icon-pencil',
		'fields' => array(
			array(
				'id'       => 'content_bg_color',
				'type'     => 'color_rgba',
				'title'    => esc_html__( 'Background Color', 'medcaline' ),
				'subtitle' => esc_html__( 'Content background color.', 'medcaline' ),
				'output'   => array( 'background-color' => 'body' )
			),
			array(
				'id'             => 'content_padding',
				'type'           => 'spacing',
				'output'         => array( '#content' ),
				'right'          => false,
				'left'           => false,
				'mode'           => 'padding',
				'units'          => array( 'px' ),
				'units_extended' => 'false',
				'title'          => esc_html__( 'Content Padding', 'medcaline' ),
				'desc'           => esc_html__( 'Default: Theme Option.', 'medcaline' ),
				'default'        => array(
					'padding-top'    => '',
					'padding-bottom' => '',
					'units'          => 'px',
				)
			),
			array(
				'id'      => 'show_sidebar_page',
				'type'    => 'switch',
				'title'   => esc_html__( 'Show Sidebar', 'medcaline' ),
				'default' => false,
				'indent'  => true
			),
			array(
				'id'           => 'sidebar_page_pos',
				'type'         => 'button_set',
				'title'        => esc_html__( 'Sidebar Position', 'medcaline' ),
				'options'      => array(
					'left'  => esc_html__( 'Left', 'medcaline' ),
					'right' => esc_html__( 'Right', 'medcaline' ),
				),
				'default'      => 'right',
				'required'     => array( 0 => 'show_sidebar_page', 1 => '=', 2 => '1' ),
				'force_output' => true
			),
		)
	) );

    $metabox->add_section('page', array(
        'title' => esc_html__('Footer', 'medcaline'),
        'desc' => esc_html__('Settings for page footer.', 'medcaline'),
        'icon' => 'el el-website',
        'fields' => array(
            array(
                'id'      => 'custom_footer',
                'type'    => 'switch',
                'title'   => esc_html__( 'Custom Footer', 'medcaline' ),
                'default' => false,
                'indent'  => true
            ),
            array(
                'id'       => 'footer_layout',
                'type'     => 'button_set',
                'title'    => esc_html__('Layout', 'medcaline'),
                'subtitle' => esc_html__('Select a layout for upper footer area.', 'medcaline'),
                'options'  => array(
                    '1'  => esc_html__('Default', 'medcaline'),
                    'custom'  => esc_html__('Custom', 'medcaline'),
                    '0'  => esc_html__('No footer', 'medcaline'),

                ),
                'default'  => '1',
                'required' => array( 0 => 'custom_footer', 1 => 'equals', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'          => 'footer_layout_custom',
                'type'        => 'select',
                'title'       => esc_html__('Custom Layout', 'medcaline'),
                'desc'        => sprintf(esc_html__('To use this Option please %sClick Here%s to add your custom footer layout first.','medcaline'),'<a href="' . esc_url( admin_url( 'edit.php?post_type=footer' ) ) . '">','</a>'),
                'options'     => medcaline_list_post('footer'),
                'default'     => '',
                'required' => array( 0 => 'footer_layout', 1 => 'equals', 2 => 'custom' ),
                'force_output' => true
            ),
        )
    ));

	$metabox->add_section( 'product', array(
		'title'  => esc_html__( 'Header', 'medcaline' ),
		'desc'   => esc_html__( 'Header settings for the page.', 'medcaline' ),
		'icon'   => 'el-icon-website',
		'fields' => array(
			array(
				'id'      => 'custom_header',
				'type'    => 'switch',
				'title'   => esc_html__( 'Custom Header', 'medcaline' ),
				'default' => false,
				'indent'  => true
			),
			array(
				'id'           => 'header_layout',
				'type'         => 'image_select',
				'title'        => esc_html__( 'Layout', 'medcaline' ),
				'subtitle'     => esc_html__( 'Select a layout for header.', 'medcaline' ),
				'options'      => array(
					'0' => get_template_directory_uri() . '/assets/images/header-layout/h0.jpg',
					'1' => get_template_directory_uri() . '/assets/images/header-layout/h1.jpg',
					'2' => get_template_directory_uri() . '/assets/images/header-layout/h2.jpg',
					'3' => get_template_directory_uri() . '/assets/images/header-layout/h3.jpg',
                    '4' => get_template_directory_uri() . '/assets/images/header-layout/h4.jpg',
				),
				'default'      => medcaline_get_option_of_theme_options( 'header_layout' ),
				'required'     => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
				'force_output' => true
			),
		)
	) );

    /**
     * Config Case Study meta options
     *
     */
    $metabox->add_section( 'case-study', array(
        'title'  => esc_html__( 'Page Title', 'medcaline' ),
        'icon'   => 'el el-indent-left',
        'fields' => array(
            array(
                'id'           => 'custom_pagetitle',
                'type'         => 'button_set',
                'title'        => esc_html__( 'Page Title', 'medcaline' ),
                'options'      => array(
                    'themeoption'  => esc_html__( 'Theme Option', 'medcaline' ),
                    'hide'  => esc_html__( 'Elementor Content', 'medcaline' ),
                ),
                'default'      => 'themeoption',
                'desc'           => esc_html__( 'Inherit from Theme Option or build-in Elementor Content', 'medcaline' ),
            ),
        )
    ) );
    $metabox->add_section( 'case-study', array(
        'title'  => esc_html__( 'Content', 'medcaline' ),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
            array(
                'id'             => 'case_study_content_padding',
                'type'           => 'spacing',
                'output'         => array( '.single-case-study #content'),
                'right'          => false,
                'left'           => false,
                'mode'           => 'padding',
                'units'          => array( 'px' ),
                'units_extended' => 'false',
                'title'          => esc_html__( 'Content Padding', 'medcaline' ),
                'desc'           => esc_html__( 'Default: Theme Option.', 'medcaline' ),
                'default'        => array(
                    'padding-top'    => '',
                    'padding-bottom' => '',
                    'units'          => 'px',
                )
            ),
        )
    ) );
    $metabox->add_section( 'case-study', array(
        'title'  => esc_html__( 'Information', 'medcaline' ),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
            array(
                'id'           => 'case_customer',
                'type'         => 'text',
                'title'        => esc_html__( 'Customer', 'medcaline' ),
                'force_output' => true
            ),
            array(
                'id'           => 'case_signs',
                'type'         => 'text',
                'title'        => esc_html__( 'Signs', 'medcaline' ),
                'force_output' => true
            ),
            array(
                'id'           => 'case_result',
                'type'         => 'text',
                'title'        => esc_html__( 'Result', 'medcaline' ),
                'force_output' => true
            ),
        )
    ) );

    /**
     * Config Service options
     *
     */
    $metabox->add_section( 'service', array(
        'title'  => esc_html__( 'Page Title', 'medcaline' ),
        'icon'   => 'el el-indent-left',
        'fields' => array(
            array(
                'id'           => 'custom_pagetitle',
                'type'         => 'button_set',
                'title'        => esc_html__( 'Page Title', 'medcaline' ),
                'options'      => array(
                    'themeoption'  => esc_html__( 'Theme Option', 'medcaline' ),
                    'hide'  => esc_html__( 'Elementor Content', 'medcaline' ),
                ),
                'default'      => 'themeoption',
                'desc'           => esc_html__( 'Inherit from Theme Option or build-in Elementor Content', 'medcaline' ),
            ),
        )
    ) );
    $metabox->add_section( 'service', array(
        'title'  => esc_html__( 'Content', 'medcaline' ),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
            array(
                'id'             => 'service_content_padding',
                'type'           => 'spacing',
                'output'         => array( '.single-service #content'),
                'right'          => false,
                'left'           => false,
                'mode'           => 'padding',
                'units'          => array( 'px' ),
                'units_extended' => 'false',
                'title'          => esc_html__( 'Content Padding', 'medcaline' ),
                'desc'           => esc_html__( 'Default: Theme Option.', 'medcaline' ),
                'default'        => array(
                    'padding-top'    => '',
                    'padding-bottom' => '',
                    'units'          => 'px',
                )
            ),
        )
    ) );
    $metabox->add_section( 'service', array(
        'title'  => esc_html__( 'Additional Info', 'medcaline' ),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
            array(
                'id' => 'service_icon',
                'type' => 'media',
                'title' => esc_html__('Service Icon Image', 'medcaline'),
                'desc'           => esc_html__( 'Default image size is 38x38 px', 'medcaline' ),
            ),
        )
    ) );

    /**
     * Config Team meta options
     *
     */
    $metabox->add_section( 'lq-team', array(
        'title'  => esc_html__( 'Page Title', 'medcaline' ),
        'icon'   => 'el el-indent-left',
        'fields' => array(
            array(
                'id'           => 'custom_pagetitle',
                'type'         => 'button_set',
                'title'        => esc_html__( 'Page Title', 'medcaline' ),
                'options'      => array(
                    'themeoption'  => esc_html__( 'Theme Option', 'medcaline' ),
                    'show'  => esc_html__( 'Custom', 'medcaline' ),
                    'hide'  => esc_html__( 'Hide', 'medcaline' ),
                ),
                'default'      => 'themeoption',
            ),
            array(
                'id'       => 'team_ptitle_bg',
                'type'     => 'background',
                'title'    => esc_html__('Background', 'medcaline'),
                'subtitle' => esc_html__('Page title background.', 'medcaline'),
                'output'   => array('body.single-lq-team #pagetitle.pagetitle'),
                'required' => array( 0 => 'custom_pagetitle', 1 => 'equals', 2 => 'show' ),
                'force_output' => true,
                'transparent' => false,
                'background-color'     => false,
            ),
            array(
                'id'             => 'team_ptitle_padding',
                'type'           => 'spacing',
                'output'         => array('body #pagetitle.pagetitle'),
                'right'   => false,
                'left'    => false,
                'mode'           => 'padding',
                'units'          => array('px'),
                'units_extended' => 'false',
                'title'          => esc_html__('Page Title Padding', 'medcaline'),
                'default'            => array(
                    'padding-top'   => '',
                    'padding-bottom'   => '',
                    'units'          => 'px',
                ),
                'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
                'force_output' => true
            ),
            array(
                'id'      => 'page_breadcrumb_on',
                'type'    => 'switch',
                'title'   => esc_html__( 'Breadcrumb', 'medcaline' ),
                'default' => false,
                'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
            ),
        )
    ) );
    $metabox->add_section( 'lq-team', array(
        'title'  => esc_html__( 'Content', 'medcaline' ),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
            array(
                'id'             => 'team_content_padding',
                'type'           => 'spacing',
                'output'         => array( '.single-lq-team #content'),
                'right'          => false,
                'left'           => false,
                'mode'           => 'padding',
                'units'          => array( 'px' ),
                'units_extended' => 'false',
                'title'          => esc_html__( 'Content Padding', 'medcaline' ),
                'desc'           => esc_html__( 'Default: Theme Option.', 'medcaline' ),
                'default'        => array(
                    'padding-top'    => '',
                    'padding-bottom' => '',
                    'units'          => 'px',
                )
            ),
            array(
                'id'      => 'team_show_contact',
                'type'    => 'switch',
                'title'   => esc_html__( 'Show Contact Form', 'medcaline' ),
                'subtitle' => esc_html__('Show form contact on single.', 'medcaline'),
                'default' => true,
                'indent'  => true
            ),
            array(
                'id' => 'team_contact_form',
                'type' => 'select',
                'title' => esc_html__('Select Contact Form', 'medcaline'),
                'options' => $contact_forms,
                'default' => '',
                'required' => array(0 => 'team_show_contact', 1 => 'equals', 2 => true),
                'force_output' => true
            ),
        )
    ) );
    $metabox->add_section( 'lq-team', array(
        'title'  => esc_html__( 'Information', 'medcaline' ),
        'icon'   => 'el el-address-book',
        'fields' => array(
            array(
                'id'           => 'team_phone',
                'type'         => 'text',
                'title'        => esc_html__( 'Phone', 'medcaline' ),
                'force_output' => true
            ),
            array(
                'id'           => 'team_mail',
                'type'         => 'text',
                'title'        => esc_html__( 'Mail', 'medcaline' ),
                'force_output' => true
            ),
            array(
                'id'           => 'team_experience',
                'type'         => 'text',
                'title'        => esc_html__( 'Experience', 'medcaline' ),
                'force_output' => true
            ),
            array(
                'id'           => 'team_position',
                'type'         => 'text',
                'title'        => esc_html__( 'Position', 'medcaline' ),
                'force_output' => true
            ),
            array(
                'id'           => 'team_location',
                'type'         => 'text',
                'title'        => esc_html__( 'Location', 'medcaline' ),
                'force_output' => true
            ),
            array(
                'id'=>'team_download',
                'type' => 'textarea',
                'title' => esc_html__('Html Download Button', 'medcaline'),
                'validate' => 'html_custom',
                'default' => '',
                'allowed_html' => array(
                    'a' => array(
                        'href' => array(),
                        'title' => array(),
                        'class' => array(),
                        'target'=> array(),
                    ),
                    'i' => array(
                        'class' => array(),
                    ),
                    'span' => array(),
                    'p' => array(),
                    'div' => array(
                        'class' => array()
                    ),
                )
            ),
        )
    ) );
    $metabox->add_section( 'lq-team', array(
        'title'  => esc_html__( 'Social Media', 'medcaline' ),
        'icon'   => 'el el-twitter',
        'fields' => array(
            array(
                'id'      => 'team_facebook_url',
                'type'    => 'text',
                'title'   => esc_html__('Facebook URL', 'medcaline'),
                'default' => '#',
            ),
            array(
                'id'      => 'team_twitter_url',
                'type'    => 'text',
                'title'   => esc_html__('Twitter URL', 'medcaline'),
                'default' => '#',
            ),
            array(
                'id'      => 'team_skype_url',
                'type'    => 'text',
                'title'   => esc_html__('Skype URL', 'medcaline'),
                'default' => '#',
            ),
            array(
                'id'      => 'team_instagram_url',
                'type'    => 'text',
                'title'   => esc_html__('Instagram URL', 'medcaline'),
                'default' => '#',
            ),
            array(
                'id'      => 'team_pinterest_url',
                'type'    => 'text',
                'title'   => esc_html__('Pinterest URL', 'medcaline'),
                'default' => '',
            ),
            array(
                'id'      => 'team_youtube_url',
                'type'    => 'text',
                'title'   => esc_html__('Youtube URL', 'medcaline'),
                'default' => '',
            ),
        )
    ) );
}

function medcaline_get_option_of_theme_options( $key, $default = '' ) {
	if ( empty( $key ) ) {
		return '';
	}
	$options = get_option( medcaline_get_opt_name(), array() );
	$value   = isset( $options[ $key ] ) ? $options[ $key ] : $default;

	return $value;
}