<?php
/**
 * Custom template tags for this theme.
 *
 * @package Medcaline
 */

/**
 * Header layout
 **/
function medcaline_page_loading()
{
    $page_loading = medcaline_get_opt('show_page_loading', false);
    $page_loading_style = medcaline_get_opt('page_loading_style', '');

    if ($page_loading) {
        switch ( $page_loading_style ) {
            case 'style2': ?>
                <div id="cms-loadding" class="cms-loader style2">
                    <div class="google-dots ball-jump">
                        <span class="ball-1"></span>
                        <span class="ball-2"></span>
                        <span class="ball-3"></span>
                        <span class="ball-4"></span>
                    </div>
                </div>
                <?php break;
            case 'style3': ?>
                <div id="cms-loadding" class="cms-loader style3">
                    <div class="loadingio-spinner-heart">
                        <div class="lq-heart-run">
                            <div>
                                <div></div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php break;
            default: ?>
                <div id="cms-loadding" class="cms-loader default">
                    <div class="lq-loading-spinner">
                        <div class="lq-spinner-run">
                            <div style='left:35px;top:35px;animation-delay:0s'></div>
                            <div style='left:51px;top:35px;animation-delay:0.2s'></div>
                            <div style='left:35px;top:51px;animation-delay:0.6s'></div>
                            <div style='left:51px;top:51px;animation-delay:0.4s'></div>
                        </div>
                    </div>
                </div>
                <?php break;
        }
    }
}

/**
 * Header layout
 **/
function medcaline_header_layout()
{
    $header_layout = medcaline_get_opt('header_layout', '1');
    $custom_header = medcaline_get_page_opt('custom_header', '0');
    $slide_nav_on = medcaline_get_opt('slide_nav_on', false);

    if ($custom_header == '1' && !is_search()) {
        $page_header_layout = medcaline_get_page_opt('header_layout');
        $header_layout = $page_header_layout;
        if ($header_layout == '0') {
            return;
        }
    }

    get_template_part('template-parts/header-layout', $header_layout);
    if ($header_layout == '1') {
        if ($slide_nav_on) {
            get_template_part('template-parts/slide-nav');
        }
    }
}

/**
 * Page title layout
 **/
function medcaline_page_title_layout()
{
    get_template_part('template-parts/page-title', '');
}

/**
 * Page title layout
 **/
function medcaline_footer()
{
    if (is_404()) {
        return true;
    }
    $footer_layout = medcaline_get_opt('footer_layout', 'custom');

    if (is_page()) {
        $page_footer_layout = medcaline_get_page_opt('footer_layout');
        $footer_layout = $page_footer_layout;
    }
    if ($footer_layout == '0') {
        return true;
    }
    get_template_part('template-parts/footer-layout-custom');
}

/**
 * Set primary content class based on sidebar position
 *
 * @param  string $sidebar_pos
 * @param  string $extra_class
 */
function medcaline_primary_class($sidebar_pos, $extra_class = '')
{
    if (class_exists('WooCommerce') && (is_product_category()) || class_exists('WooCommerce') && (is_shop())) :
        $sidebar_load = 'sidebar-shop';
    else :
        $sidebar_load = 'sidebar-blog';
    endif;

    if (is_active_sidebar($sidebar_load)) {
        $class = array(trim($extra_class));
        switch ($sidebar_pos) {
            case 'left':
                $class[] = 'content-has-sidebar float-right col-xl-8 col-lg-8 col-md-12';
                break;

            case 'right':
                $class[] = 'content-has-sidebar float-left col-xl-8 col-lg-8 col-md-12';
                break;

            default:
                $class[] = 'content-full-width col-12';
                break;
        }

        $class = implode(' ', array_filter($class));

        if ($class) {
            echo ' class="' . esc_html($class) . '"';
        }
    } else {
        echo ' class="content-area col-12"';
    }
}

/**
 * Set secondary content class based on sidebar position
 *
 * @param  string $sidebar_pos
 * @param  string $extra_class
 */
function medcaline_secondary_class($sidebar_pos, $extra_class = '')
{
    if (class_exists('WooCommerce') && (is_product_category())) :
        $sidebar_load = 'sidebar-shop';
    elseif (is_page()) :
        $sidebar_load = 'sidebar-page';
    elseif (is_post_type_archive('recipe') || is_tax('recipe-diet')) :
        $sidebar_load = 'sidebar-recipe';
    else :
        $sidebar_load = 'sidebar-blog';
    endif;

    if (is_active_sidebar($sidebar_load)) {
        $class = array(trim($extra_class));
        switch ($sidebar_pos) {
            case 'left':
                $class[] = 'widget-has-sidebar sidebar-fixed col-xl-4 col-lg-4 col-md-12';
                break;
            case 'right':
                $class[] = 'widget-has-sidebar sidebar-fixed col-xl-4 col-lg-4 col-md-12';
                break;
            default:
                break;
        }

        $class = implode(' ', array_filter($class));

        if ($class) {
            echo ' class="' . esc_html($class) . '"';
        }
    }
}


/**
 * Prints HTML for breadcrumbs.
 */
function medcaline_breadcrumb()
{
    if (!class_exists('CMS_Breadcrumb')) {
        return;
    }

    $breadcrumb = new CMS_Breadcrumb();
    $entries = $breadcrumb->get_entries();

    if (empty($entries)) {
        return;
    }

    ob_start();

    foreach ($entries as $entry) {
        $entry = wp_parse_args($entry, array(
            'label' => '',
            'url' => ''
        ));

        if (empty($entry['label'])) {
            continue;
        }

        echo '<li>';

        if (!empty($entry['url'])) {
            printf(
                '<a class="breadcrumb-entry" href="%1$s">%2$s</a>',
                esc_url($entry['url']),
                esc_attr($entry['label'])
            );
        } else {
            printf('<span class="breadcrumb-entry" >%s</span>', esc_html($entry['label']));
        }

        echo '</li>';
    }

    $output = ob_get_clean();

    if ($output) {
        printf('<ul class="cms-breadcrumb">%s</ul>', wp_kses_post($output));
    }
}


function medcaline_entry_link_pages()
{
    wp_link_pages(array(
        'before' => '<div class="page-links">',
        'after' => '</div>',
        'link_before' => '<span>',
        'link_after' => '</span>',
    ));
}


if (!function_exists('medcaline_entry_excerpt')) :
    /**
     * Print post excerpt based on length.
     *
     * @param  integer $length
     */
    function medcaline_entry_excerpt($length = 55)
    {
        $cms_the_excerpt = get_the_excerpt();
        if (!empty($cms_the_excerpt)) {
            echo wp_trim_words($cms_the_excerpt, $length, $more = null);
        } else {
            echo wp_kses_post(medcaline_get_the_excerpt($length));
        }
    }
endif;

/**
 * Prints post edit link when applicable
 */
function medcaline_entry_edit_link()
{
    edit_post_link(
        sprintf(
            wp_kses(
            /* translators: %s: Name of current post. Only visible to screen readers */
                esc_html__('Edit', 'medcaline'),
                array(
                    'span' => array(
                        'class' => array(),
                    ),
                )
            ),
            get_the_title()
        ),
        '<div class="entry-edit-link"><i class="fa fa-edit"></i>',
        '</div>'
    );
}

if (!function_exists('medcaline_ajax_paginate_links')) {
    function medcaline_ajax_paginate_links($link)
    {
        $parts = parse_url($link);
        parse_str($parts['query'], $query);
        if (isset($query['page']) && !empty($query['page'])) {
            return '#' . $query['page'];
        } else {
            return '#1';
        }
    }
}

add_action('wp_ajax_medcaline_get_pagination_html', 'medcaline_get_pagination_html');
add_action('wp_ajax_nopriv_medcaline_get_pagination_html', 'medcaline_get_pagination_html');
if (!function_exists('medcaline_get_pagination_html')) {
    function medcaline_get_pagination_html()
    {
        try {
            if (!isset($_POST['query_vars'])) {
                throw new Exception(esc_html__('Something went wrong while requesting. Please try again!', 'medcaline'));
            }
            $query = new WP_Query($_POST['query_vars']);
            ob_start();
            medcaline_posts_pagination($query, true);
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => esc_html__('Load Successfully!', 'medcaline'),
                    'data' => array(
                        'html' => $html,
                        'query_vars' => $_POST['query_vars'],
                        'post' => $query->have_posts()
                    ),
                )
            );
        } catch (Exception $e) {
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}

/**
 * Prints posts pagination based on query
 *
 * @param  WP_Query $query Custom query, if left blank, this will use global query ( current query )
 * @return void
 */
function medcaline_posts_pagination($query = null, $ajax = false)
{
    if ($ajax) {
        add_filter('paginate_links', 'medcaline_ajax_paginate_links');
    }

    $classes = array();

    if (empty($query)) {
        $query = $GLOBALS['wp_query'];
    }

    if (empty($query->max_num_pages) || !is_numeric($query->max_num_pages) || $query->max_num_pages < 2) {
        return;
    }

    $paged = $query->get('paged', '');

    if (!$paged && is_front_page() && !is_home()) {
        $paged = $query->get('page', '');
    }

    $paged = $paged ? intval($paged) : 1;

    $pagenum_link = html_entity_decode(get_pagenum_link());
    $query_args = array();
    $url_parts = explode('?', $pagenum_link);

    if (isset($url_parts[1])) {
        wp_parse_str($url_parts[1], $query_args);
    }

    $pagenum_link = remove_query_arg(array_keys($query_args), $pagenum_link);
    $pagenum_link = trailingslashit($pagenum_link) . '%_%';

    $html_prev = '<i class="fa fa-angle-double-left" aria-hidden="true"></i>';
    $html_next = '<i class="fa fa-angle-double-right" aria-hidden="true"></i>';
    $paginate_links_args = array(
        'base' => $pagenum_link,
        'total' => $query->max_num_pages,
        'current' => $paged,
        'mid_size' => 1,
        'add_args' => array_map('urlencode', $query_args),
        'prev_text' => $html_prev,
        'next_text' => $html_next,
    );
    if ($ajax) {
        $paginate_links_args['format'] = '?page=%#%';
    }
    $links = paginate_links($paginate_links_args);
    if ($links):
        ?>
        <nav class="navigation posts-pagination <?php echo esc_attr($ajax ? 'ajax' : ''); ?>">
            <div class="posts-page-links">
                <?php
                printf($links);
                ?>
            </div>
        </nav>
    <?php
    endif;
}

/**
 * Prints archive meta on blog
 */
if (!function_exists('medcaline_archive_meta')) :
    function medcaline_archive_meta()
    {
        $archive_author_on = medcaline_get_opt('archive_author_on', true);
        $archive_date_on = medcaline_get_opt('archive_date_on', true);
        $archive_categories_on = medcaline_get_opt('archive_categories_on', true);
        $archive_comments_on = medcaline_get_opt('archive_comments_on', true);
        if ($archive_author_on || $archive_date_on || $archive_categories_on || $archive_comments_on) : ?>
            <ul class="entry-meta">
                <?php if ($archive_author_on) : ?>
                    <li class="item-author">
                        <i class="zmdi zmdi-account-circle"></i>
                        <span><?php echo esc_html__('By', 'medcaline'); ?></span>
                        <?php the_author_posts_link(); ?>
                    </li>
                <?php endif; ?>
                <?php if ($archive_date_on) : ?>
                    <li class="item-date">
                        <i class="zmdi zmdi-calendar-note"></i>
                        <?php echo get_the_date(); ?>
                    </li>
                <?php endif; ?>
                <?php if ($archive_categories_on && !empty(get_the_terms(get_the_ID(),'category'))) : ?>
                    <li class="item-category">
                        <i class="zmdi zmdi-folder"></i>
                        <?php the_terms(get_the_ID(), 'category', '', ', '); ?>
                    </li>
                <?php endif; ?>
                <?php if ($archive_comments_on) : ?>
                    <li class="item-comment">
                        <i class="zmdi zmdi-comment-more"></i>
                        <a href="<?php the_permalink(); ?>"><?php comments_number(esc_html__('No Comments', 'medcaline'), esc_html__('Comment: 1', 'medcaline'), esc_html__('Comments: %', 'medcaline')); ?></a>
                    </li>
                <?php endif; ?>
            </ul>
        <?php endif;
    }
endif;

if (!function_exists('medcaline_post_meta')) :
    function medcaline_post_meta()
    {
        $post_author_on = medcaline_get_opt('post_author_on', true);
        $post_date_on = medcaline_get_opt('post_date_on', true);
        $post_categories_on = medcaline_get_opt('post_categories_on', true);
        $post_comments_on = medcaline_get_opt('post_comments_on', true);
        if ($post_author_on || $post_date_on || $post_categories_on || $post_comments_on) : ?>
            <ul class="entry-meta">
                <?php if ($post_author_on) : ?>
                    <li class="item-author">
                        <i class="zmdi zmdi-account-circle"></i>
                        <span><?php echo esc_html__('By', 'medcaline'); ?></span>
                        <?php the_author_posts_link(); ?>
                    </li>
                <?php endif; ?>
                <?php if ($post_date_on) : ?>
                    <li class="item-date">
                        <i class="zmdi zmdi-calendar-note"></i>
                        <?php echo get_the_date(); ?>
                    </li>
                <?php endif; ?>
                <?php if ($post_categories_on) : ?>
                    <li class="item-category">
                        <i class="zmdi zmdi-folder"></i>
                        <?php the_terms(get_the_ID(), 'category', '', ', '); ?>
                    </li>
                <?php endif; ?>
                <?php if ($post_comments_on) : ?>
                    <li class="item-comment">
                        <i class="zmdi zmdi-comment-more"></i>
                        <a href="<?php the_permalink(); ?>"><?php comments_number(esc_html__('No Comments', 'medcaline'), esc_html__('Comment: 1', 'medcaline'), esc_html__('Comments: %', 'medcaline')); ?></a>
                    </li>
                <?php endif; ?>
            </ul>
        <?php endif;
    }
endif;

/**
 * Prints tag list
 */
if (!function_exists('medcaline_entry_tagged_in')) :
    /**
     * Prints HTML with meta information for the current post-date/time.
     */
    function medcaline_entry_tagged_in()
    {
        $tags_list = get_the_tag_list('<label>'.esc_html__('Tags:', 'medcaline').'</label>', ',');
        if ($tags_list) {
            echo '<div class="entry-tags">';
            printf('%2$s', '', $tags_list);
            echo '</div>';
        }
    }
endif;

/**
 * List socials share for post.
 */
function medcaline_socials_share_default($post_id = 0)
{
    if ($post_id == 0) {
        ?>
        <ul>
            <li><a class="fb-social" title="Facebook" target="_blank"
                   href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>"><i class="fab fa-facebook-f"></i></a></li>
            <li><a class="tw-social" title="Twitter" target="_blank"
                   href="https://twitter.com/home?status=<?php the_permalink(); ?>"><i class="fab fa-twitter"></i></a></li>
            <li><a class="pin-social" title="Pinterest" target="_blank"
                   href="https://pinterest.com/pin/create/button/?url=<?php the_post_thumbnail_url('full'); ?>&media=&description=<?php echo urlencode(the_title_attribute('echo=0')); ?>"><i class="fab fa-pinterest-p"></i></a></li>
            <li><a class="g-social" title="Google Plus" target="_blank"
                   href="https://plus.google.com/share?url=<?php the_permalink(); ?>"><i class="fab fa-google"></i></a>
            </li>
        </ul>
        <?php
    } else {
        $post = get_post($post_id);
        if ($post) {
            ?>
            <ul>
                <li><a class="fb-social" title="Facebook" target="_blank"
                       href="https://www.facebook.com/sharer/sharer.php?u=<?php echo esc_url(get_the_permalink($post_id)); ?>"><i class="fab fa-facebook-f"></i></a></li>
                <li><a class="tw-social" title="Twitter" target="_blank"
                       href="https://twitter.com/home?status=<?php echo esc_url(get_the_permalink($post_id)); ?>"><i class="fab fa-twitter"></i></a></li>
                <li><a class="pin-social" title="Pinterest" target="_blank"
                       href="https://pinterest.com/pin/create/button/?url=<?php echo esc_url(get_the_post_thumbnail_url($post_id, 'full')); ?>&media=&description=<?php echo urlencode(the_title_attribute(array('echo' => false, 'post' => $post))); ?>"><i class="fab fa-pinterest-p"></i></a></li>
                <li><a class="g-social" title="Google Plus" target="_blank"
                       href="https://plus.google.com/share?url=<?php echo esc_url(get_the_permalink($post_id)); ?>"><i class="fab fa-google"></i></a></li>
            </ul>
            <?php
        }
    }
}

/**
 * Footer Top
 */
function medcaline_footer_top()
{
    $footer_top_column = medcaline_get_opt('footer_top_column');
    if (empty($footer_top_column))
        return;
    $_class = "";
    switch ($footer_top_column) {
        case '2':
            $_class = 'col-xl-6 col-lg-6 col-md-6 col-sm-12';
            break;
        case '3':
            $_class = 'col-xl-4 col-lg-4 col-md-4 col-sm-12';
            break;
        case '4':
            $_class = 'col-xl-3 col-lg-3 col-md-6 col-sm-12';
            break;
    }
    for ($i = 1; $i <= $footer_top_column; $i++) {
        if (is_active_sidebar('sidebar-footer-' . $i)) {
            echo '<div class="cms-footer-item ' . esc_html($_class) . '">';
            dynamic_sidebar('sidebar-footer-' . $i);
            echo "</div>";
        }
    }
}

/**
 * Search Popup
 */
function medcaline_search_popup()
{
    $search_on = medcaline_get_opt('search_on', false);
    if ($search_on) { ?>
        <div class="cms-modal cms-modal-search">
            <div class="cms-modal-close">x</div>
            <div class="cms-modal-content">
                <form role="search" method="get" class="search-form-popup"
                      action="<?php echo esc_url(home_url('/')); ?>">
                    <div class="searchform-wrap">
                        <input type="text" placeholder="<?php echo esc_attr__('Enter Keywords...', 'medcaline'); ?>"
                               id="search" name="s" class="search-field"/>
                        <button type="submit" class="search-submit"><i class="fa fa-search"></i></button>
                    </div>
                </form>
            </div>
        </div>
    <?php }
}

function medcaline_social_share_product()
{ ?>
    <a class="fb-social hover-effect" title="Facebook" target="_blank"
       href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>"><i class="zmdi zmdi-facebook"></i></a>
    <a class="tw-social hover-effect" title="Twitter" target="_blank"
       href="https://twitter.com/home?status=<?php the_permalink(); ?>"><i class="zmdi zmdi-twitter"></i></a>
    <a class="g-social hover-effect" title="Google Plus" target="_blank"
       href="https://plus.google.com/share?url=<?php the_permalink(); ?>"><i class="zmdi zmdi-google-plus"></i></a>
    <a class="pin-social hover-effect" title="Pinterest" target="_blank"
       href="https://pinterest.com/pin/create/button/?url=<?php echo esc_url(the_post_thumbnail_url('full')); ?>&media=&description=<?php the_title(); ?>"><i
                class="zmdi zmdi-pinterest"></i></a>
    <?php
}

function medcaline_product_nav()
{
    if ( is_singular('product') ) {
        global $post;
        // get categories
        $terms = wp_get_post_terms( $post->ID, 'product_cat' );
        foreach ( $terms as $term ) $cats_array[] = $term->term_id;
        // get all posts in current categories
        $query_args = array('posts_per_page' => -1, 'post_status' => 'publish', 'post_type' => 'product', 'tax_query' => array(
            array(
                'taxonomy' => 'product_cat',
                'field' => 'id',
                'terms' => $cats_array
            )));
        $r = new WP_Query($query_args);
        // show next and prev only if we have 3 or more
        if ($r->post_count > 2) {
            $prev_product_id = -1;
            $next_product_id = -1;
            $found_product = false;
            $i = 0;
            //Tony get current post from out of loop
            $current_product_index = $i;
            $current_product_id = get_the_ID();
            if ($r->have_posts()) {
                while ($r->have_posts()) {
                    $r->the_post();
                    $current_id = get_the_ID();
                    if ($current_id == $current_product_id) {
                        $found_product = true;
                        $current_product_index = $i;
                    }
                    //Keep find and change prev product until current product is found
                    if (!$found_product && $current_id != $current_product_id) {
                        $prev_product_id = get_the_ID();
                    }
                    //After current product is found
                    if ($found_product && $i == $current_product_index + 1) {
                        $next_product_id = get_the_ID();
                    }
                    $i++;
                }
                // Show button nav
                if ($prev_product_id != -1) {
                    ?>
                    <div class="product-nav prev-nav">
                        <a href="<?php echo esc_attr(get_the_permalink($prev_product_id)); ?>" title="<?php echo esc_attr(get_the_title($prev_product_id))?>">
                            <i class="zmdi zmdi-long-arrow-left"></i>
                            <ul class="font-smooth">
                                <li><?php echo esc_html__('Previous Product', 'medcaline');?></li>
                                <li><?php echo esc_html(get_the_title($prev_product_id));?></li>
                            </ul>
                        </a>
                    </div>
                    <?php
                }
                if ($next_product_id != -1) {
                    ?>
                    <div class="product-nav next-nav">
                        <a href="<?php echo esc_attr(get_the_permalink($next_product_id)); ?>" title="<?php echo esc_attr(get_the_title($next_product_id))?>">
                            <i class="zmdi zmdi-long-arrow-right"></i>
                            <ul class="font-smooth">
                                <li><?php echo esc_html__('Next Product', 'medcaline');?></li>
                                <li><?php echo esc_html(get_the_title($next_product_id));?></li>
                            </ul>
                        </a>
                    </div>
                    <?php
                }
            }
            wp_reset_postdata();
        }
    }
}

/**
 * Display navigation to next/previous post when applicable.
 */
function medcaline_post_nav_default()
{
    global $post;
    // Don't print empty markup if there's nowhere to navigate.
    $previous = (is_attachment()) ? get_post($post->post_parent) : get_adjacent_post(false, '', true);
    $next = get_adjacent_post(false, '', false);

    if (!$next && !$previous)
        return;
    ?>
    <?php
    $next_post = get_next_post();
    $previous_post = get_previous_post();
    if (!empty($next_post) || !empty($previous_post)) { ?>
        <div class="post-previous-next default">
            <div class="nav-links row clearfix">
                <div class="nav-link-prev grid-item col-xl-6 col-lg-6 col-md-6 col-sm-12 col-12">
                    <?php if (is_a($previous_post, 'WP_Post') && get_the_title($previous_post->ID) != '') {
                        $url_prev = wp_get_attachment_image_src(get_post_thumbnail_id($previous_post->ID), 'thumbnail', false);
                        $image_alt = get_post_meta(get_post_thumbnail_id($previous_post->ID), '_wp_attachment_image_alt', true);
                        if (empty($image_alt)) {
                            $image_alt = get_the_title($previous_post->ID);
                        }
                        ?>
                        <div class="grid-item-inner">
                            <?php if (!empty($url_prev[0])) { ?>
                                <div class="item-featured">
                                    <a href="<?php echo esc_url(get_permalink($previous_post->ID)); ?>"
                                       class="image-link">
                                        <img src="<?php echo esc_url($url_prev[0]); ?>"
                                             alt="<?php echo esc_attr($image_alt); ?>"/>
                                        <div class="nav-arrow"><i class="zmdi zmdi-arrow-left"></i></div>
                                    </a>
                                </div>
                            <?php } ?>
                            <div class="item-holder">
                                <span><?php esc_html_e('Previous', 'medcaline') ?></span>
                                <p class="item-title">
                                    <a href="<?php echo esc_url(get_permalink($previous_post->ID)); ?>"><?php echo get_the_title($previous_post->ID); ?></a>
                                </p>
                            </div>
                        </div>
                    <?php } ?>
                </div>
                <div class="nav-link-next grid-item col-xl-6 col-lg-6 col-md-6 col-sm-12 col-12">
                    <?php if (is_a($next_post, 'WP_Post') && get_the_title($next_post->ID) != '') {
                        $url_next = wp_get_attachment_image_src(get_post_thumbnail_id($next_post->ID), 'thumbnail', false);
                        $image_alt = get_post_meta(get_post_thumbnail_id($next_post->ID), '_wp_attachment_image_alt', true);
                        if (empty($image_alt)) {
                            $image_alt = get_the_title($next_post->ID);
                        }
                        ?>
                        <div class="grid-item-inner">
                            <div class="item-holder">
                                <span><?php esc_html_e('Next', 'medcaline') ?></span>
                                <p class="item-title">
                                    <a href="<?php echo esc_url(get_permalink($next_post->ID)); ?>"><?php echo get_the_title($next_post->ID); ?></a>
                                </p>
                            </div>
                            <?php if (!empty($url_next[0])) { ?>
                                <div class="item-featured">
                                    <a href="<?php echo esc_url(get_permalink($next_post->ID)); ?>" class="image-link">
                                        <img src="<?php echo esc_url($url_next[0]); ?>"
                                             alt="<?php echo esc_attr($image_alt); ?>"/>
                                        <div class="nav-arrow"><i class="zmdi zmdi-arrow-right"></i></div>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    <?php } ?>
                </div>
            </div><!-- .nav-links -->
        </div>
    <?php }
}

/**
 * Custom Widget Categories
 */
add_filter('wp_list_categories', 'medcaline_cat_count_span');
function medcaline_cat_count_span($output) {
    $dir = is_rtl() ? 'left' : 'right';
    $output = str_replace("\t", '', $output);
    $output = str_replace(")\n</li>", ')</li>', $output);
    $output = str_replace('</a> (', ' <span class="count '.$dir.'">(', $output);
    $output = str_replace(")</li>", ") </span></li>", $output);
    $output = str_replace(")\n<ul", ") </span>\n<ul", $output);
    return $output;
}

/**
 * Custom Widget Archive
 */
add_filter('get_archives_link', 'medcaline_archive_count_span');
function medcaline_archive_count_span($links) {
    $dir = is_rtl() ? 'left' : 'right';
    $links = str_replace('</a>&nbsp;(', ' <span class="count '.$dir.'">(', $links);
    $links = str_replace(')', ') </span></a>', $links);
    return $links;
}

/**
 * Custom Widget Product Categories
 */
add_filter('wp_list_categories', 'medcaline_wc_cat_count_span');
function medcaline_wc_cat_count_span($links) {
    $dir = is_rtl() ? 'left' : 'right';
    $links = str_replace('</a> <span class="count">', ' <span class="count '.$dir.'">', $links);
    $links = str_replace('</span>', '</span></a>', $links);
    return $links;
}


/**
 * Animate
 */

function medcaline_animate() {
    $cms_animate = array(
        '' => 'None',
        'wow bounce' => 'bounce',
        'wow flash' => 'flash',
        'wow pulse' => 'pulse',
        'wow rubberBand' => 'rubberBand',
        'wow shake' => 'shake',
        'wow swing' => 'swing',
        'wow tada' => 'tada',
        'wow wobble' => 'wobble',
        'wow bounceIn' => 'bounceIn',
        'wow bounceInDown' => 'bounceInDown',
        'wow bounceInLeft' => 'bounceInLeft',
        'wow bounceInRight' => 'bounceInRight',
        'wow bounceInUp' => 'bounceInUp',
        'wow bounceOut' => 'bounceOut',
        'wow bounceOutDown' => 'bounceOutDown',
        'wow bounceOutLeft' => 'bounceOutLeft',
        'wow bounceOutRight' => 'bounceOutRight',
        'wow bounceOutUp' => 'bounceOutUp',
        'wow fadeIn' => 'fadeIn',
        'wow fadeInUp' => 'fadeInUp',
        'wow fadeInUpBig' => 'fadeInUpBig',
        'wow fadeInDown' => 'fadeInDown',
        'wow fadeInDownBig' => 'fadeInDownBig',
        'wow fadeInLeft' => 'fadeInLeft',
        'wow fadeInLeftBig' => 'fadeInLeftBig',
        'wow fadeInRight' => 'fadeInRight',
        'wow fadeInRightBig' => 'fadeInRightBig',
        'wow fadeOut' => 'fadeOut',
        'wow fadeOutDown' => 'fadeOutDown',
        'wow fadeOutDownBig' => 'fadeOutDownBig',
        'wow fadeOutLeft' => 'fadeOutLeft',
        'wow fadeOutLeftBig' => 'fadeOutLeftBig',
        'wow fadeOutRight' => 'fadeOutRight',
        'wow fadeOutRightBig' => 'fadeOutRightBig',
        'wow fadeOutUp' => 'fadeOutUp',
        'wow fadeOutUpBig' => 'fadeOutUpBig',
        'wow flip' => 'flip',
        'wow flipInX' => 'flipInX',
        'wow flipInY' => 'flipInY',
        'wow flipOutX' => 'flipOutX',
        'wow flipOutY' => 'flipOutY',
        'wow lightSpeedIn' => 'lightSpeedIn',
        'wow lightSpeedOut' => 'lightSpeedOut',
        'wow rotateIn' => 'rotateIn',
        'wow rotateInDownLeft' => 'rotateInDownLeft',
        'wow rotateInDownRight' => 'rotateInDownRight',
        'wow rotateInUpLeft' => 'rotateInUpLeft',
        'wow rotateInUpRight' => 'rotateInUpRight',
        'wow rotateOut' => 'rotateOut',
        'wow rotateOutDownLeft' => 'rotateOutDownLeft',
        'wow rotateOutDownRight' => 'rotateOutDownRight',
        'wow rotateOutUpLeft' => 'rotateOutUpLeft',
        'wow rotateOutUpRight' => 'rotateOutUpRight',
        'wow hinge' => 'hinge',
        'wow rollIn' => 'rollIn',
        'wow rollOut' => 'rollOut',
        'wow zoomIn' => 'zoomIn',
        'wow zoomInDown' => 'zoomInDown',
        'wow zoomInLeft' => 'zoomInLeft',
        'wow zoomInRight' => 'zoomInRight',
        'wow zoomInUp' => 'zoomInUp',
        'wow zoomOut' => 'zoomOut',
        'wow zoomOutDown' => 'zoomOutDown',
        'wow zoomOutLeft' => 'zoomOutLeft',
        'wow zoomOutRight' => 'zoomOutRight',
        'wow zoomOutUp' => 'zoomOutUp',
    );
    return $cms_animate;
}

/**
 * Social Media
 */
function medcaline_social_media()
{
    $social_media = medcaline_get_opt('social_media');
    $social = $social_media['enabled'];
    if ($social) : foreach ($social as $key => $value) { ?>
        <?php switch ($key) {

            case 'facebook':
                echo '<a title="Facebook" href="' . esc_url(medcaline_get_opt('social_facebook_url')) . '"><i class="zmdi zmdi-facebook"></i></a>';
                break;

            case 'twitter':
                echo '<a title="Twitter" href="' . esc_url(medcaline_get_opt('social_twitter_url')) . '"><i class="zmdi zmdi-twitter"></i></a>';
                break;

            case 'linkedin':
                echo '<a title="Linkedin" href="' . esc_url(medcaline_get_opt('social_inkedin_url')) . '"><i class="zmdi zmdi-linkedin"></i></a>';
                break;

            case 'rss':
                echo '<a title="Rss" href="' . esc_url(medcaline_get_opt('social_rss_url')) . '"><i class="zmdi zmdi-rss"></i></i></a>';
                break;

            case 'instagram':
                echo '<a title="Instagram" href="' . esc_url(medcaline_get_opt('social_instagram_url')) . '"><i class="zmdi zmdi-instagram"></i></a>';
                break;

            case 'google':
                echo '<a title="Google+" href="' . esc_url(medcaline_get_opt('social_google_url')) . '"><i class="zmdi zmdi-google-plus"></i></a>';
                break;

            case 'skype':
                echo '<a title="Skype" href="' . esc_url(medcaline_get_opt('social_skype_url')) . '"><i class="zmdi zmdi-skype"></i></a>';
                break;

            case 'pinterest':
                echo '<a title="Pinterest" href="' . esc_url(medcaline_get_opt('social_pinterest_url')) . '"><i class="zmdi zmdi-pinterest"></i></a>';
                break;

            case 'vimeo':
                echo '<a title="Vimeo" href="' . esc_url(medcaline_get_opt('social_vimeo_url')) . '"><i class="zmdi zmdi-vimeo"></i></a>';
                break;

            case 'youtube':
                echo '<a title="Youtube" href="' . esc_url(medcaline_get_opt('social_youtube_url')) . '"><i class="zmdi zmdi-youtube"></i></a>';
                break;

            case 'yelp':
                echo '<a title="Yelp" href="' . esc_url(medcaline_get_opt('social_yelp_url')) . '"><i class="fa fa-yelp"></i></a>';
                break;

            case 'tumblr':
                echo '<a title="Tumblr" href="' . esc_url(medcaline_get_opt('social_tumblr_url')) . '"><i class="fa fa-tumblr"></i></a>';
                break;

            case 'tripadvisor':
                echo '<a title="Tripadvisor" href="' . esc_url(medcaline_get_opt('social_tripadvisor_url')) . '"><i class="fa fa-tripadvisor"></i></a>';
                break;

        }
    }
    endif;
}

/**
 * Team Social Media
 */
function medcaline_social_team() {
    $team_facebook_url = medcaline_get_page_opt( 'team_facebook_url' );
    $team_twitter_url = medcaline_get_page_opt( 'team_twitter_url' );
    $team_skype_url = medcaline_get_page_opt( 'team_skype_url' );
    $team_instagram_url = medcaline_get_page_opt( 'team_instagram_url' );
    $team_pinterest_url = medcaline_get_page_opt( 'team_pinterest_url' );
    $team_youtube_url = medcaline_get_page_opt( 'team_youtube_url' );

    if(!empty($team_facebook_url)) :
        echo '<a href="'.esc_url($team_facebook_url).'" target="_blank"><i class="zmdi zmdi-facebook"></i></a>';
    endif;
    if(!empty($team_twitter_url)) :
        echo '<a href="'.esc_url($team_twitter_url).'" target="_blank"><i class="zmdi zmdi-twitter"></i></a>';
    endif;
    if(!empty($team_skype_url)) :
        echo '<a href="'.esc_url($team_skype_url).'" target="_blank"><i class="zmdi zmdi-skype"></i></a>';
    endif;
    if(!empty($team_instagram_url)) :
        echo '<a href="'.esc_url($team_instagram_url).'" target="_blank"><i class="zmdi zmdi-instagram"></i></a>';
    endif;
    if(!empty($team_pinterest_url)) :
        echo '<a href="'.esc_url($team_pinterest_url).'" target="_blank"><i class="zmdi zmdi-pinterest"></i></a>';
    endif;
    if(!empty($team_youtube_url)) :
        echo '<a href="'.esc_url($team_youtube_url).'" target="_blank"><i class="zmdi zmdi-youtube-play"></i></a>';
    endif;
}

// Popup Contact Form
function medcaline_contact_form() {
    $h_btn_link_type = medcaline_get_opt('h_btn_link_type', 'page_link');
    $popup_contact_form = medcaline_get_opt('popup_contact_form');
    $ctf7_id = '';
    $cf7 = get_posts('post_type="wpcf7_contact_form"&numberposts=-1');
    if ($cf7) {
        foreach ($cf7 as $cform) {
            if ($cform->post_name == $popup_contact_form){
                $ctf7_id = $cform->ID;
                break;
            }
        }
    }
    $title_contact_form = medcaline_get_opt('title_contact_form');
    if(class_exists('WPCF7') && $h_btn_link_type == 'contact_form' && !empty($ctf7_id)) { ?>
        <div class="cms-modal cms-modal-contact-form">
            <div class="cms-modal-close">x</div>
            <div class="cms-modal-inner">
                <div class="cms-contact-form placeholder-dark cms-contact-form-flat style-primary">
                    <?php
                    if (!empty($title_contact_form)){
                        ?><h3 class="el-title"><?php echo esc_html($title_contact_form);?></h3><?php
                    }else{
                        ?><h3 class="el-title"><?php echo esc_html__('Request a Free Quote', 'medcaline');?></h3><?php
                    }
                    echo do_shortcode('[contact-form-7 id="'.esc_attr( $ctf7_id ).'"]');
                    ?>
                </div>
            </div>
        </div>
    <?php }
}

/**
 * Get post grid template
 */
function get_post_grid_layout1($posts = [], $settings = [])
{
    extract($settings);
    if($thumbnail_size != 'custom' && $thumbnail_size != 'full'){
        $img_size = $thumbnail_size;
    }
    elseif(!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])){
        $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    }
    else{
        $img_size = '768x568';
    }
    if (is_array($posts)):
        foreach ($posts as $post):
            $img_id = get_post_thumbnail_id($post->ID);
            $img = lcb_get_image_by_size( array(
                'attach_id'  => $img_id,
                'thumb_size' => $img_size,
                'class'      => '',
            ));
            $thumbnail = $img['thumbnail'];
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $filter_class = lcb_get_term_of_post_to_class($post->ID, array_unique($tax));

            $author = get_user_by('id', $post->post_author);
            $comment_number = get_comments_number($post->ID);
            $comment_text = esc_html__('Comments', 'medcaline');
            if ($comment_number == 1) {
                $comment_text = esc_html__('Comment', 'medcaline');
            }
            ?>
            <div class="<?php echo esc_attr($item_class . ' ' . $filter_class); ?>">
                <div class="grid-item-inner">
                    <?php if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false)): ?>
                        <div class="entry-featured scale-hover-x">
                            <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo wp_kses_post($thumbnail); ?></a>
                        </div>
                    <?php endif; ?>
                    <div class="entry-body">
                        <div class="entry-body-inner">
                            <?php if($show_title == 'true'): ?>
                                <<?php lcb_print_html($title_tag);?> class="entry-title">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" target="_blank"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                                </<?php lcb_print_html($title_tag);?>>
                            <?php endif; ?>

                            <?php if($show_meta == 'true'): ?>
                                <ul class="entry-meta">
                                    <li class="item-author">
                                        <i class="zmdi zmdi-account-circle"></i>
                                        <a href="<?php echo esc_url(get_author_posts_url($post->post_author, $author->user_nicename)); ?>">
                                            <?php echo esc_html__('By', 'medcaline') . ' ' . esc_html($author->display_name); ?>
                                        </a>
                                    </li>
                                    <li class="item-date">
                                        <i class="zmdi zmdi-calendar-note"></i>
                                        <?php $date_formart = get_option('date_format');
                                        echo get_the_date($date_formart, $post->ID); ?>
                                    </li>
                                    <li class="item-comment">
                                        <i class="zmdi zmdi-comment-more"></i>
                                        <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html($comment_number) . ' ' . esc_html($comment_text); ?></a>
                                    </li>
                                </ul>
                            <?php endif; ?>
                            <?php if($show_excerpt == 'true'): ?>
                                <div class="entry-content">
                                    <?php
                                    if(!empty($post->post_excerpt)){
                                        echo wp_trim_words( $post->post_excerpt, $num_words, $more = '.' );
                                    }
                                    else{
                                        $content = strip_shortcodes( $post->post_content );
                                        $content = apply_filters( 'the_content', $content );
                                        $content = str_replace(']]>', ']]&gt;', $content);
                                        $content = wp_trim_words( $content, $num_words, '&hellip;' );
                                        echo wp_kses_post($content);
                                    }
                                    ?>
                                </div>
                            <?php endif; ?>
                            <?php if($show_button == 'true'): ?>
                                <div class="action-buttons">
                                    <div class="entry-readmore">
                                        <a class="btn-more" href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo esc_attr($button_text); ?><i class="zmdi zmdi-chevron-right"></i></a>
                                    </div>
                                </div>
                            <?php endif; ?>
                        </div>
                </div>
            </div>
            </div>
        <?php
        endforeach;
    endif;
}

function get_post_list_layout1($posts = [], $settings = [])
{
    extract($settings);
    if (is_array($posts)):
        foreach ($posts as $post):
            $item_class = "grid-item col-xl-12 col-lg-12 col-md-12 col-sm-12 col-12";
            $author = get_user_by('id', $post->post_author);
            $comment_number = get_comments_number($post->ID);
            $comment_text = esc_html__('Comments', 'medcaline');
            if ($comment_number == 1) {
                $comment_text = esc_html__('Comment', 'medcaline');
            }
            $tags = get_the_tags($post->ID);
            ?>
            <div class="<?php echo esc_attr($item_class); ?>">
                <div class="grid-item-inner">
                    <?php
                    if ( $show_thumbnail == 'true'){
                        medcaline_post_format_featured($post->ID);
                    }
                    ?>
                    <div class="entry-body">
                        <div class="entry-body-inner">
                            <div class="inner-left">
                                <div class="post-date">
                                    <div class="day-month">
                                        <div class="date-day"><?php echo get_the_date('d', $post->ID)  ?></div>
                                        <div class="date-month"><?php echo get_the_date('F', $post->ID)  ?></div>
                                    </div>
                                    <div class="date-year"><?php echo get_the_date('Y', $post->ID)  ?></div>
                                </div>
                            </div>
                            <div class="inner-right">
                                <h3 class="item-title">
                                    <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                                </h3>
                                <ul class="entry-meta font-smooth">
                                    <li class="author">
                                        <i class="zmdi zmdi-account-circle"></i>
                                        <span><?php echo esc_html__('By', 'medcaline') . ' ';?></span>
                                        <a href="<?php echo esc_url(get_author_posts_url($post->post_author, $author->user_nicename)); ?>"><?php echo esc_html($author->display_name); ?></a>
                                    </li>
                                    <li>
                                        <i class="zmdi zmdi-comment-more"></i>
                                        <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html($comment_number) . ' ' . esc_html($comment_text); ?></a>
                                    </li>
                                    <?php if( !empty($tags) ){ ?>
                                        <li class="item-tags">
                                            <i class="icofont-tag"></i>
                                            <?php foreach($tags as $tag) :  ?>
                                                <a href="<?php echo esc_url( home_url() ); ?>/tag/<?php print_r($tag->slug);?>"><?php print_r($tag->name); ?></a>
                                            <?php endforeach; ?>
                                        </li>
                                    <?php } ?>
                                </ul>
                                <div class="item-content">
                                    <?php
                                    if (!empty($post->post_excerpt)) {
                                        echo wp_trim_words($post->post_excerpt, $num_words, $more = '.');
                                    } else {
                                        $content = strip_shortcodes($post->post_content);
                                        $content = apply_filters('the_content', $content);
                                        $content = str_replace(']]>', ']]&gt;', $content);
                                        $content = wp_trim_words($content, $num_words, '&hellip;');
                                        echo wp_kses_post($content);
                                    }
                                    ?>
                                </div>
                                <div class="action-buttons">
                                    <div class="item-readmore">
                                        <a class="btn" href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html($button_text); ?><i class="zmdi zmdi-chevron-right"></i></a>
                                    </div>
                                    <?php if ($social_share) {
                                        ?>
                                        <div class="entry-social-share">
                                            <?php medcaline_socials_share_default($post->ID); ?>
                                        </div>
                                        <?php
                                    } ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    endif;
}
function get_team_grid_layout1($posts = [], $settings = [])
{
    extract($settings);
    if ($thumbnail_size != 'custom') {
        $img_size = $thumbnail_size;
    } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
        $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    } else {
        $img_size = 'full';
    }
    if (is_array($posts)):
        foreach ($posts as $post):
            $img_id = get_post_thumbnail_id($post->ID);
            $img = lcb_get_image_by_size(array(
                'attach_id' => $img_id,
                'thumb_size' => $img_size,
                'class' => '',
            ));
            $thumbnail = $img['thumbnail'];
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $filter_class = lcb_get_term_of_post_to_class($post->ID, array_unique($tax));
            // Social Info
            $team_facebook = get_post_meta($post->ID, 'team_facebook_url', true);
            $team_twitter = get_post_meta($post->ID, 'team_twitter_url', true);
            $team_skype = get_post_meta($post->ID, 'team_skype_url', true);
            $team_instagram = get_post_meta($post->ID, 'team_instagram_url', true);
            $team_pinterest = get_post_meta($post->ID, 'team_pinterest_url', true);
            $team_youtube = get_post_meta($post->ID, 'team_youtube_url', true);
            ?>
            <div class="<?php echo esc_attr($item_class . ' ' . $filter_class); ?>">
                <div class="grid-item-inner <?php if (!empty($cms_animate)){echo esc_attr($cms_animate);} ?>" data-wow-duration="1.3s">
                    <?php if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false)): ?>
                        <div class="entry-featured">
                            <div class="post-image scale-hover">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo wp_kses_post($thumbnail); ?></a>
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="entry-body">
                        <div class="entry-body-inner">
                            <h3 class="entry-title">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                            </h3>
                            <div class="lq-team-category">
                                <?php the_terms( $post->ID, 'lq-team-category', '', ', ' ); ?>
                            </div>
                            <?php if ($show_excerpt == 'true'): ?>
                                <div class="entry-content">
                                    <?php
                                    if (!empty($post->post_excerpt)) {
                                        echo wp_trim_words($post->post_excerpt, $num_words, $more = '.');
                                    } else {
                                        $content = strip_shortcodes($post->post_content);
                                        $content = apply_filters('the_content', $content);
                                        $content = str_replace(']]>', ']]&gt;', $content);
                                        $content = wp_trim_words($content, $num_words, '&hellip;');
                                        echo wp_kses_post($content);
                                    }
                                    ?>
                                </div>
                            <?php endif; ?>
                            <?php if ($show_social == 'true'): ?>
                                <div class="team-social">
                                    <ul class="info-social">
                                        <?php if(!empty($team_facebook)) : ?>
                                            <li><a href="<?php echo esc_url($team_facebook); ?>"><i class="zmdi zmdi-facebook"></i></a></li>
                                        <?php endif; ?>
                                        <?php if(!empty($team_twitter)) : ?>
                                            <li><a href="<?php echo esc_url($team_twitter); ?>"><i class="zmdi zmdi-twitter"></i></a></li>
                                        <?php endif; ?>
                                        <?php if(!empty($team_skype)) : ?>
                                            <li><a href="<?php echo esc_attr($team_skype); ?>"><i class="zmdi zmdi-skype"></i></a></li>
                                        <?php endif; ?>
                                        <?php if(!empty($team_instagram)) : ?>
                                            <li><a href="<?php echo esc_attr($team_instagram); ?>"><i class="zmdi zmdi-instagram"></i></a></li>
                                        <?php endif; ?>
                                        <?php if(!empty($team_pinterest)) : ?>
                                            <li><a href="<?php echo esc_attr($team_pinterest); ?>"><i class="zmdi zmdi-pinterest"></i></a></li>
                                        <?php endif; ?>
                                        <?php if(!empty($team_youtube)) : ?>
                                            <li><a href="<?php echo esc_attr($team_youtube); ?>"><i class="zmdi zmdi-youtube-play"></i></a></li>
                                        <?php endif; ?>
                                    </ul>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    endif;
}
function get_product_grid_layout1($posts = [], $settings = [])
{
    extract($settings);
    if($thumbnail_size != 'custom'){
        $img_size = $thumbnail_size;
    }
    elseif(!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])){
        $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    }
    else{
        $img_size = '370x435';
    }
    if (is_array($posts)):
        foreach ($posts as $post):
            $img_id = get_post_thumbnail_id($post->ID);
            $img = lcb_get_image_by_size( array(
                'attach_id'  => $img_id,
                'thumb_size' => $img_size,
                'class'      => '',
            ));
            $thumbnail = $img['thumbnail'];
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $filter_class = lcb_get_term_of_post_to_class($post->ID, array_unique($tax));
            $product = wc_get_product( $post->ID );
            $regular_price = get_post_meta( $post->ID, '_regular_price', true);
            $sale_price = get_post_meta( $post->ID, '_sale_price', true);
            $product_sale = '';
            ?>
            <div class="<?php echo esc_attr($item_class . ' ' . $filter_class); ?>">
                <div class="grid-item-inner woocommerce-product-inner">
                    <?php
                    if(!empty($sale_price) && $product->is_on_sale()) {
                        $product_sale = intval( ( (intval($regular_price) - intval($sale_price)) / intval($regular_price) ) * 100);
                        echo '<span class="onsale">'.esc_html__('Sale', 'medcaline').' '.$product_sale.'%</span>';
                    }
                    ?>
                    <?php if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false)): ?>
                        <div class="item-featured woocommerce-product-header">
                            <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo wp_kses_post($thumbnail); ?></a>
                            <div class="woocommerce-add-to-cart">
                                <?php
                                echo apply_filters( 'woocommerce_loop_add_to_cart_link',
                                    sprintf( '<a href="%s" rel="nofollow" data-product_id="%s" data-product_sku="%s" class="button ajax_add_to_cart %s product_type_%s">%s</a>',
                                        esc_url( $product->add_to_cart_url() ),
                                        esc_attr( $product->get_id() ),
                                        esc_attr( $product->get_sku() ),
                                        $product->is_purchasable() ? 'add_to_cart_button' : '',
                                        esc_attr( $product->get_type() ),
                                        esc_html( $product->add_to_cart_text() )
                                    ),
                                    $product );
                                ?>
                            </div>
                        </div>
                    <?php endif; ?>
                    <div class="woocommerce-product-holder">
                        <h3 class="woocommerce-product-title"><a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a></h3>
                        <span class="price"><?php echo wp_kses_post($product->get_price_html()); ?></span>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    endif;
}

function get_case_study_grid_layout1($posts = [], $settings = [])
{
    extract($settings);
    if ($thumbnail_size != 'custom') {
        $img_size = $thumbnail_size;
    } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
        $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    } else {
        $img_size = 'full';
    }
    if (is_array($posts)):
        foreach ($posts as $post):
            $img_id = get_post_thumbnail_id($post->ID);
            $img = lcb_get_image_by_size(array(
                'attach_id' => $img_id,
                'thumb_size' => $img_size,
                'class' => '',
            ));
            $thumbnail = $img['thumbnail'];
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $filter_class = lcb_get_term_of_post_to_class($post->ID, array_unique($tax));
            ?>
            <div class="<?php echo esc_attr($item_class . ' ' . $filter_class); ?>">
                <div class="grid-item-inner <?php if (!empty($cms_animate)){echo esc_attr($cms_animate);} ?>" data-wow-duration="1.3s">
                    <?php if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false)): ?>
                        <div class="entry-featured">
                            <div class="post-image scale-hover-x">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo wp_kses_post($thumbnail); ?></a>
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="entry-body">
                        <div class="entry-body-inner">
                            <div class="case-study-category">
                                <?php the_terms( $post->ID, 'case-study-category', '', ', ' ); ?>
                            </div>
                            <h3 class="entry-title">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                            </h3>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    endif;
}

function get_service_grid_layout1($posts = [], $settings = [])
{
    extract($settings);
    if ($thumbnail_size != 'custom') {
        $img_size = $thumbnail_size;
    } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
        $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    } else {
        $img_size = 'full';
    }
    if (is_array($posts)):
        foreach ($posts as $post):
            $img_id = get_post_thumbnail_id($post->ID);
            $img = lcb_get_image_by_size(array(
                'attach_id' => $img_id,
                'thumb_size' => $img_size,
                'class' => '',
            ));
            $thumbnail = $img['thumbnail'];
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $icon_image = get_post_meta($post->ID, 'service_icon',true);
            ?>
            <div class="<?php echo esc_attr($item_class); ?>">
                <div class="grid-item-inner square-box <?php if (!empty($cms_animate)){echo esc_attr($cms_animate);} ?>" data-wow-duration="1.3s">
                    <div class="inner-box">
                        <?php if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false) && $show_thumbnail == 'true'): ?>
                            <div class="entry-featured">
                                <div class="post-image scale-hover-x">
                                    <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo wp_kses_post($thumbnail); ?></a>
                                </div>
                                <?php
                                if (!empty($icon_image['url']) && $show_icon == 'true' ){
                                    ?>
                                    <div class="service-icon-wrap">
                                        <img class="service-icon" src="<?php echo esc_url($icon_image['url']); ?>" alt="<?php echo esc_attr($icon_image['alt']); ?>">
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                        <?php endif; ?>
                        <div class="entry-body">
                            <div class="entry-body-inner">
                                <?php if ($show_title == 'true'): ?>
                                <<?php lcb_print_html($title_tag); ?> class="entry-title">
                                    <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                                </<?php lcb_print_html($title_tag); ?>>
                                <?php endif; ?>

                                <?php if ($show_excerpt == 'true'): ?>
                                <div class="entry-content">
                                    <?php
                                    if (!empty($post->post_excerpt)) {
                                        echo wp_trim_words($post->post_excerpt, $num_words, $more = '.');
                                    } else {
                                        $content = strip_shortcodes($post->post_content);
                                        $content = apply_filters('the_content', $content);
                                        $content = str_replace(']]>', ']]&gt;', $content);
                                        $content = wp_trim_words($content, $num_words, '&hellip;');
                                        echo wp_kses_post($content);
                                    }
                                    ?>
                                </div>
                                <?php endif; ?>
                                <div class="action-buttons">
                                    <?php if ($show_button == 'true'): ?>
                                        <div class="entry-readmore">
                                            <a class="btn btn-outline secondary" href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html($button_text); ?></a>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    endif;
}

function get_service_grid_layout2($posts = [], $settings = [])
{
    extract($settings);
    if (is_array($posts)):
        foreach ($posts as $post):
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $icon_image = get_post_meta($post->ID, 'service_icon',true);
            if (!empty($icon_image['url'])){
                $background_url = $icon_image['url'];
            }
            ?>
            <div class="<?php echo esc_attr($item_class); ?>">
                <div class="grid-item-inner <?php if (!empty($cms_animate)){echo esc_attr($cms_animate);} ?>" data-wow-duration="1.3s">
                    <div class="item-overlay">
                        <img src="<?php echo esc_url($icon_image['url']); ?>" alt="<?php echo esc_attr(get_the_title($post->ID)); ?>" />
                    </div>
                    <div class="entry-body">
                        <?php if ($show_title == 'true'): ?>
                            <<?php lcb_print_html($title_tag); ?> class="entry-title">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                            </<?php lcb_print_html($title_tag); ?>>
                        <?php endif; ?>
                        <div class="body-bottom">
                            <?php
                            if (!empty($icon_image['url']) && $show_icon == 'true' ){
                                ?>
                                <div class="bottom-left">
                                    <img class="service-icon" src="<?php echo esc_url($icon_image['url']); ?>" alt="<?php echo esc_attr($icon_image['alt']); ?>">
                                </div>
                                <?php
                            }
                            ?>
                            <div class="bottom-right">
                                <?php if ($show_excerpt == 'true'): ?>
                                    <div class="entry-content">
                                        <?php
                                        if (!empty($post->post_excerpt)) {
                                            echo wp_trim_words($post->post_excerpt, $num_words, $more = '.');
                                        } else {
                                            $content = strip_shortcodes($post->post_content);
                                            $content = apply_filters('the_content', $content);
                                            $content = str_replace(']]>', ']]&gt;', $content);
                                            $content = wp_trim_words($content, $num_words, '&hellip;');
                                            echo wp_kses_post($content);
                                        }
                                        ?>
                                    </div>
                                <?php endif; ?>
                                <div class="action-buttons">
                                    <?php if ($show_button == 'true'): ?>
                                        <div class="entry-readmore">
                                            <a class="btn-more" href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo esc_attr($button_text); ?><i class="zmdi zmdi-chevron-right"></i></a>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    endif;
}

if (!function_exists('medcaline_get_post_grid')) {
    function medcaline_get_post_grid($posts = [], $settings = [])
    {
        if (empty($posts) || !is_array($posts) || empty($settings) || !is_array($settings)) {
            return false;
        }
        switch ($settings['template_type']) {
            case 'post_grid_layout1':
                get_post_grid_layout1($posts, $settings);
                break;
            case 'post_list_layout1':
                get_post_list_layout1($posts, $settings);
                break;
            case 'case_study_grid_layout1':
                get_case_study_grid_layout1($posts, $settings);
                break;
            case 'service_grid_layout1':
                get_service_grid_layout1($posts, $settings);
                break;
            case 'service_grid_layout2':
                get_service_grid_layout2($posts, $settings);
                break;
            case 'team_grid_layout1':
                get_team_grid_layout1($posts, $settings);
                break;
            case 'product_grid_layout1':
                get_product_grid_layout1($posts, $settings);
                break;
            default:
                return false;
                break;
        }
    }
}


add_action('wp_ajax_medcaline_load_more_post_grid', 'medcaline_load_more_post_grid');
add_action('wp_ajax_nopriv_medcaline_load_more_post_grid', 'medcaline_load_more_post_grid');

if (!function_exists('medcaline_load_more_post_grid')) {
    function medcaline_load_more_post_grid()
    {
        try {
            if (!isset($_POST['settings'])) {
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'medcaline'));
            }
            $settings = $_POST['settings'];
            set_query_var('paged', $settings['paged']);
            extract(lcb_get_posts_of_grid($settings['posttype'], [
                'source' => isset($settings['source']) ? $settings['source'] : '',
                'orderby' => isset($settings['orderby']) ? $settings['orderby'] : 'date',
                'order' => isset($settings['order']) ? $settings['order'] : 'desc',
                'limit' => isset($settings['limit']) ? $settings['limit'] : '6',
                'post_ids' => '',
            ]));
            ob_start();
            medcaline_get_post_grid($posts, $settings);
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => esc_html__('Load Successfully!', 'medcaline'),
                    'data' => array(
                        'html' => $html,
                        'paged' => $settings['paged'],
                        'posts' => $posts,
                    ),
                )
            );
        } catch (Exception $e) {
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}

// Get featured image
function medcaline_get_FB_image($post_ID) {
    $post_thumbnail_id = get_post_thumbnail_id( $post_ID );
    if ($post_thumbnail_id) {
        $post_thumbnail_img = wp_get_attachment_image_src( $post_thumbnail_id, 'thumbnail');
        return $post_thumbnail_img[0];
    }
}

// Get post excerpt
function medcaline_get_FB_description($post) {
    if (!empty($post->post_excerpt)) {
        return $post->post_excerpt;
    }
    else {
        $excerpt_length = 55;
        $text = "";
        if (!empty($post->post_content)){
            $text = str_replace("\r\n"," ", strip_tags(strip_shortcodes($post->post_content)));
        }
        $words = explode(' ', $text, $excerpt_length + 1);
        if (count($words) > $excerpt_length) {
            array_pop($words);
            $excerpt = implode(' ', $words);
            return $excerpt;
        }
    }
}

function medcaline_FB_header() {
    global $post;
    $post_description = medcaline_get_FB_description($post);
    $post_featured_image = "";
    if (is_single()){
        $post_featured_image = medcaline_get_FB_image($post->ID);
    }
    if ( !empty($post_featured_image) && !empty($post_description) )  { ?>
        <meta name="title" content="<?php echo ''.$post->post_title; ?>" />
        <meta name="description" content="<?php echo ''.$post_description; ?>" />
        <link rel="image_src" href="<?php echo ''.$post_featured_image; ?>" />
    <?php }
}
add_action('wp_head', 'medcaline_FB_header');

/**
 * Cart Sidebar
 */
function medcaline_cart_sidebar() {
    $cart_on = medcaline_get_opt( 'cart_on', false );
    ?>
    <?php if(class_exists('Woocommerce') && $cart_on) : ?>
        <div class="cms-widget-cart-wrap">
            <div class="cms-widget-cart-overlay"></div>
            <div class="cms-widget-cart-sidebar">
                <div class="cms-close"><i class="zmdi zmdi-close"></i></div>
                <div class="widget_shopping_cart">
                    <div class="widget_shopping_cart_content">
                        <?php woocommerce_mini_cart(); ?>
                    </div>
                </div>
            </div>
        </div>
    <?php endif; ?>
<?php }

/**
 * Show Cart Sidebar Hidden
 */
add_action('wp_ajax_nopriv_item_added', 'medcaline_addedtocart_sweet_message');
add_action('wp_ajax_item_added', 'medcaline_addedtocart_sweet_message');

function medcaline_addedtocart_sweet_message() {
    echo isset($_POST['id']) && $_POST['id'] > 0 ? (int) esc_attr($_POST['id']) : false;
    die();
}
add_action('wp_footer', 'medcaline_product_count_check');
function medcaline_product_count_check() {
    if (class_exists('Woocommerce') && is_checkout())
        return;
    ?>
    <script type="text/javascript">
        jQuery( function($) {
            if ( typeof wc_add_to_cart_params === 'undefined' )
                return false;

            $(document.body).on( 'added_to_cart', function( event, fragments, cart_hash, $button ) {
                var $pid = $button.data('product_id');

                $.ajax({
                    type: 'POST',
                    url: wc_add_to_cart_params.ajax_url,
                    data: {
                        'action': 'item_added',
                        'id'    : $pid
                    },
                    success: function (response) {
                        $('.cms-widget-cart-wrap').addClass('open');
                    }
                });
            });
        });
    </script>
    <?php
}
