<?php
if (!class_exists('ReduxFramework')) {
    return;
}
if (class_exists('ReduxFrameworkPlugin')) {
    remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
}
if (class_exists('WPCF7')) {
    $cf7 = get_posts('post_type="wpcf7_contact_form"&numberposts=-1');

    $contact_forms = array();
    if ($cf7) {
        foreach ($cf7 as $cform) {
            $contact_forms[$cform->post_name] = $cform->post_title;
        }
    } else {
        $contact_forms[esc_html__('No contact forms found', 'medcaline')] = 0;
    }
} else {
    $contact_forms = '';
}
$opt_name = medcaline_get_opt_name();
$theme = wp_get_theme();

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name'             => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name'         => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version'      => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type'            => class_exists('Liquid_Custom_Builder') ? 'submenu' : '',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => true,
    // Show the sections below the admin menu item or not
    'menu_title'           => esc_html__('Theme Options', 'medcaline'),
    'page_title'           => esc_html__('Theme Options', 'medcaline'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => 'dashicons-admin-generic',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode'             => true,
    // Show the time the page took to load, lcb
    'update_notice'        => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
    'show_options_object' => false,
    // OPTIONAL -> Give you extra features
    'page_priority'        => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => class_exists('Liquid_Custom_Builder') ? $theme->get('TextDomain') : '',
    // For a full list of options, visit: //codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => '',
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug'            => 'theme-options',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn'              => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints'                => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    ),
    'templates_path'       => get_template_directory() . '/inc/templates/redux/'
);

Redux::SetArgs($opt_name, $args);

/*--------------------------------------------------------------
# General
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('General', 'medcaline'),
    'icon'   => 'el-icon-home',
    'fields' => array(
        array(
            'id'       => 'favicon',
            'type'     => 'media',
            'title'    => esc_html__('Favicon', 'medcaline'),
            'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/favicon.png'
            )
        ),
        array(
            'id'       => 'show_page_loading',
            'type'     => 'switch',
            'title'    => esc_html__('Enable Page Loading', 'medcaline'),
            'subtitle' => esc_html__('Enable page loading effect when you load site.', 'medcaline'),
            'default'  => false
        ),
        array(
            'id'          => 'page_loading_style',
            'type'        => 'select',
            'title'       => esc_html__('Loading Style', 'medcaline'),
            'options'  => array(
                '' => esc_html__('Default', 'medcaline'),
                'style2'  => esc_html__('Style 2', 'medcaline'),
                'style3'  => esc_html__('Style 3', 'medcaline'),
            ),
            'default'     => '',
            'required' => array( 0 => 'show_page_loading', 1 => 'equals', 2 => true ),
            'force_output' => true
        ),
        array(
            'id'       => 'smoothscroll',
            'type'     => 'switch',
            'title'    => esc_html__('Smooth Scroll', 'medcaline'),
            'default'  => false
        ),
        array(
            'id'       => 'dev_mode',
            'type'     => 'switch',
            'title'    => esc_html__('Dev Mode (not recommended)', 'medcaline'),
            'description' => 'no minimize , generate css over time...',
            'default'  => false
        ),
    )
));

/*--------------------------------------------------------------
# Header
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Header', 'medcaline'),
    'icon'   => 'el-icon-website',
    'fields' => array(
        array(
            'id'       => 'header_layout',
            'type'     => 'image_select',
            'title'    => esc_html__('Layout', 'medcaline'),
            'subtitle' => esc_html__('Select a layout for header.', 'medcaline'),
            'options'  => array(
                '1' => get_template_directory_uri() . '/assets/images/header-layout/h1.jpg',
                '2' => get_template_directory_uri() . '/assets/images/header-layout/h2.jpg',
                '3' => get_template_directory_uri() . '/assets/images/header-layout/h3.jpg',
                '4' => get_template_directory_uri() . '/assets/images/header-layout/h4.jpg',
            ),
            'default'  => '1'
        ),
        array(
            'id'       => 'sticky_on',
            'type'     => 'switch',
            'title'    => esc_html__('Sticky Header', 'medcaline'),
            'subtitle' => esc_html__('Header will be sticked when applicable.', 'medcaline'),
            'default'  => false
        ),
        array(
            'id'       => 'search_on',
            'type'     => 'switch',
            'title'    => esc_html__('Search Icon', 'medcaline'),
            'default'  => false
        ),
        array(
            'id'       => 'cart_on',
            'type'     => 'switch',
            'title'    => esc_html__('Cart Icon', 'medcaline'),
            'default'  => false
        ),
    )
));


Redux::setSection($opt_name, array(
    'title'      => esc_html__('Logo', 'medcaline'),
    'icon'       => 'el el-picture',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'logo_light',
            'type'     => 'media',
            'title'    => esc_html__('Logo Light', 'medcaline'),
            'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/logo-light.png'
            )
        ),
        array(
            'id'       => 'logo',
            'type'     => 'media',
            'title'    => esc_html__('Logo Dark', 'medcaline'),
             'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/logo-dark.png'
            )
        ),
        array(
            'id'       => 'logo_mobile',
            'type'     => 'media',
            'title'    => esc_html__('Logo Tablet & Mobile', 'medcaline'),
             'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/logo-dark.png'
            )
        ),
        array(
            'id'       => 'logo_maxh',
            'type'     => 'dimensions',
            'title'    => esc_html__('Logo Max height', 'medcaline'),
            'subtitle' => esc_html__('Set maximum height for your logo, just in case the logo is too large.', 'medcaline'),
            'width'    => false,
            'unit'     => 'px'
        ),
        array(
            'id'       => 'logo_maxh_sm',
            'type'     => 'dimensions',
            'title'    => esc_html__('Logo Max height Tablet & Mobile', 'medcaline'),
            'width'    => false,
            'unit'     => 'px'
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Navigation', 'medcaline'),
    'icon'       => 'el el-lines',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'font_menu',
            'type'        => 'typography',
            'title'       => esc_html__('Custom Google Font', 'medcaline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'font-style'  => false,
            'font-weight'  => true,
            'text-align'  => false,
            'font-size'  => false,
            'line-height'  => false,
            'color'  => false,
            'output'      => array('.primary-menu > li > a, body .primary-menu .sub-menu li a'),
            'units'       => 'px',
        ),
        array(
            'id'       => 'menu_font_size',
            'type'     => 'text',
            'title'    => esc_html__('Font Size', 'medcaline'),
            'validate' => 'numeric',
            'desc'     => 'Enter number',
            'msg'      => 'Please enter number',
            'default'  => ''
        ),
        array(
            'id'       => 'menu_text_transform',
            'type'     => 'select',
            'title'    => esc_html__('Text Transform', 'medcaline'),
            'options'  => array(
                '' => esc_html__('Uppercase', 'medcaline'),
                'capitalize'  => esc_html__('Capitalize', 'medcaline'),
                'lowercase'  => esc_html__('Lowercase', 'medcaline'),
                'initial'  => esc_html__('Initial', 'medcaline'),
                'inherit'  => esc_html__('Inherit', 'medcaline'),
                'none'  => esc_html__('None', 'medcaline'),
            ),
            'default'  => ''
        ),
        array(
            'title' => esc_html__('Main Menu', 'medcaline'),
            'type'  => 'section',
            'id' => 'main_menu',
            'indent' => true
        ),
        array(
            'id'      => 'main_menu_color',
            'type'    => 'link_color',
            'title'   => esc_html__('Color', 'medcaline'),
            'default' => array(
                'regular' => '',
                'hover'   => '',
                'active'   => '',
            ),
        ),
        array(
            'title' => esc_html__('Sticky Menu', 'medcaline'),
            'type'  => 'section',
            'id' => 'sticky_menu',
            'indent' => true
        ),
        array(
            'id'      => 'sticky_menu_color',
            'type'    => 'link_color',
            'title'   => esc_html__('Color', 'medcaline'),
            'default' => array(
                'regular' => '',
                'hover'   => '',
                'active'   => '',
            ),
        ),
        array(
            'title' => esc_html__('Button Navigation', 'medcaline'),
            'type'  => 'section',
            'id' => 'button_navigation',
            'indent' => true
        ),
        array(
            'id'       => 'h_btn_on',
            'type'     => 'button_set',
            'title'    => esc_html__('Show/Hide Button', 'medcaline'),
            'options'  => array(
                'show'  => esc_html__('Show', 'medcaline'),
                'hide'  => esc_html__('Hide', 'medcaline')
            ),
            'default'  => 'hide',
        ),
        array(
            'id' => 'h_btn_text',
            'type' => 'text',
            'title' => esc_html__('Button Text', 'medcaline'),
            'default' => '',
            'required' => array( 0 => 'h_btn_on', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),
        array(
            'id'       => 'h_btn_link_type',
            'type'     => 'button_set',
            'title'    => esc_html__('Button Link Type', 'medcaline'),
            'options'  => array(
                'page'  => esc_html__('Page', 'medcaline'),
                'custom'  => esc_html__('Custom', 'medcaline'),
                'contact_form' => esc_html__('Popup Contact Form 7', 'medcaline'),
            ),
            'default'  => 'page',
            'required' => array( 0 => 'h_btn_on', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),
        array(
            'id'    => 'h_btn_link',
            'type'  => 'select',
            'title' => esc_html__( 'Page Link', 'medcaline' ),
            'data'  => 'page',
            'args'  => array(
                'post_type'      => 'page',
                'posts_per_page' => -1,
                'orderby'        => 'title',
                'order'          => 'ASC',
            ),
            'required' => array( 0 => 'h_btn_link_type', 1 => 'equals', 2 => 'page' ),
            'force_output' => true
        ),
        array(
            'id' => 'h_btn_link_custom',
            'type' => 'text',
            'title' => esc_html__('Custom Link', 'medcaline'),
            'default' => '',
            'required' => array( 0 => 'h_btn_link_type', 1 => 'equals', 2 => 'custom' ),
            'force_output' => true
        ),
        array(
            'id' => 'title_contact_form',
            'type' => 'text',
            'title' => esc_html__('Title Contact Form', 'medcaline'),
            'default' => '',
            'required' => array(0 => 'h_btn_link_type', 1 => 'equals', 2 => 'contact_form'),
            'force_output' => true
        ),
        array(
            'id' => 'popup_contact_form',
            'type' => 'select',
            'title' => __('Select Contact Form', 'medcaline'),
            'options' => $contact_forms,
            'default' => '',
            'required' => array(0 => 'h_btn_link_type', 1 => 'equals', 2 => 'contact_form'),
            'force_output' => true
        ),
        array(
            'id'       => 'h_btn_target',
            'type'     => 'button_set',
            'title'    => esc_html__('Button Target', 'medcaline'),
            'options'  => array(
                '_self'  => esc_html__('Self', 'medcaline'),
                '_blank'  => esc_html__('Blank', 'medcaline')
            ),
            'default'  => '_self',
            'required' => array( 0 => 'h_btn_on', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),
    )
));
Redux::setSection($opt_name, array(
    'title' => esc_html__('Contact Info', 'medcaline'),
    'icon' => 'el el-info-circle',
    'subsection' => true,
    'fields' => array(
        array(
            'id'      => 'ct_email',
            'type'    => 'text',
            'title'   => esc_html__('Email', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'ct_address_label',
            'type'    => 'text',
            'title'   => esc_html__('Address Label', 'medcaline'),
            'default' => '',
            'force_output' => true
        ),
        array(
            'id'      => 'ct_address',
            'type'    => 'text',
            'title'   => esc_html__('Address', 'medcaline'),
            'default' => '',
        ),
        
        array(
            'id'      => 'ct_phone_label',
            'type'    => 'text',
            'title'   => esc_html__('Phone Label', 'medcaline'),
            'default' => '',
            'force_output' => true
        ),
        array(
            'id'      => 'ct_phone',
            'type'    => 'text',
            'title'   => esc_html__('Phone Number', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'time_open_label',
            'type'    => 'text',
            'title'   => esc_html__('Time Label', 'medcaline'),
            'default' => '',
            'force_output' => true
        ),
        array(
            'id'      => 'time_open',
            'type'    => 'text',
            'title'   => esc_html__('Time', 'medcaline'),
            'default' => '',
        ),
    )
));

/*--------------------------------------------------------------
# Page Title area
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Page Title', 'medcaline'),
    'icon'   => 'el-icon-map-marker',
    'fields' => array(

        array(
            'id'           => 'pagetitle',
            'type'         => 'button_set',
            'title'        => esc_html__( 'Page Title', 'medcaline' ),
            'options'      => array(
                'show'  => esc_html__( 'Show', 'medcaline' ),
                'hide'  => esc_html__( 'Hide', 'medcaline' ),
            ),
            'default'      => 'show',
        ),

        array(
            'id'       => 'ptitle_bg',
            'type'     => 'background',
            'title'    => esc_html__('Background', 'medcaline'),
            'subtitle' => esc_html__('Page title background.', 'medcaline'),
            'output'   => array('body #pagetitle'),
            'required' => array( 0 => 'pagetitle', 1 => 'equals', 2 => 'show' ),
            'force_output' => true,
            'transparent' => false,
        ),
        array(
            'id'       => 'ptitle_color',
            'type'     => 'color',
            'title'    => esc_html__('Title Color', 'medcaline'),
            'subtitle' => esc_html__('Page title color.', 'medcaline'),
            'output'   => array('body #pagetitle h1.page-title', 'body #pagetitle .page-title-inner .cms-breadcrumb'),
            'default'  => '',
            'transparent' => false,
            'required' => array( 0 => 'pagetitle', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),
        array(
            'id' => 'ptitle_paddings',
            'type' => 'spacing',
            'title' => esc_html__('Content Paddings', 'medcaline'),
            'subtitle' => esc_html__('Content page title paddings.', 'medcaline'),
            'mode' => 'padding',
            'units' => array('em', 'px', '%'),
            'top' => true,
            'right' => false,
            'bottom' => true,
            'left' => false,
            'output' => array('#pagetitle.pagetitle'),
            'default' => array(
                'top' => '',
                'right' => '',
                'bottom' => '',
                'left' => '',
                'units' => 'px',
            )
        ),
        array(
            'id' => 'ptitle_content_align',
            'type' => 'button_set',
            'title' => esc_html__('Content Align', 'medcaline'),
            'options' => array(
                'left' => esc_html__('Left', 'medcaline'),
                'center' => esc_html__('Center', 'medcaline'),
                'right' => esc_html__('Right', 'medcaline'),
            ),
            'default' => 'center'
        ),

    )
));

/*--------------------------------------------------------------
# WordPress default content
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title' => esc_html__('Content', 'medcaline'),
    'icon'  => 'el-icon-pencil',
    'fields'     => array(
        array(
            'id'       => 'content_bg_color',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background Color', 'medcaline'),
            'subtitle' => esc_html__('Content background color.', 'medcaline'),
            'output' => array('background-color' => 'body')
        ),
        array(
            'id'             => 'content_padding',
            'type'           => 'spacing',
            'output'         => array('#content'),
            'right'   => false,
            'left'    => false,
            'mode'           => 'padding',
            'units'          => array('px'),
            'units_extended' => 'false',
            'title'          => esc_html__('Content Padding', 'medcaline'),
            'desc'           => esc_html__('Default: Top 110px, Bottom 110px', 'medcaline'),
            'default'            => array(
                'padding-top'   => '',
                'padding-bottom'   => '',
                'units'          => 'px',
            )
        ),
        array(
            'id' => 'content_sidebar_space',
            'type' => 'text',
            'title' => esc_html__('Content & Sidebar Space', 'medcaline'),
            'validate' => 'numeric',
            'desc' => 'Enter number (Default 30).',
            'msg' => 'Please enter number',
            'default' => ''
        ),
        array(
            'id'      => 'search_field_placeholder',
            'type'    => 'text',
            'title'   => esc_html__('Search Form - Text Placeholder', 'medcaline'),
            'default' => '',
            'desc'           => esc_html__('Default: Search Keywords...', 'medcaline'),
        ),
    )
));


Redux::setSection($opt_name, array(
    'title'      => esc_html__('Archive', 'medcaline'),
    'icon'       => 'el-icon-list',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'archive_sidebar_pos',
            'type'     => 'button_set',
            'title'    => esc_html__('Sidebar Position', 'medcaline'),
            'subtitle' => esc_html__('Select a sidebar position for blog home, archive, search...', 'medcaline'),
            'options'  => array(
                'left'  => esc_html__('Left', 'medcaline'),
                'right' => esc_html__('Right', 'medcaline'),
                'none'  => esc_html__('Disabled', 'medcaline')
            ),
            'default'  => 'right'
        ),
        array(
            'id'       => 'archive_author_on',
            'title'    => esc_html__('Author', 'medcaline'),
            'subtitle' => esc_html__('Show author name on each post.', 'medcaline'),
            'type'     => 'switch',
            'default'  => true,
        ),
        array(
            'id'       => 'archive_date_on',
            'title'    => esc_html__('Date', 'medcaline'),
            'subtitle' => esc_html__('Show date posted on each post.', 'medcaline'),
            'type'     => 'switch',
            'default'  => true,
        ),
        array(
            'id'       => 'archive_categories_on',
            'title'    => esc_html__('Categories', 'medcaline'),
            'subtitle' => esc_html__('Show category names on each post.', 'medcaline'),
            'type'     => 'switch',
            'default'  => true,
        ),
        array(
            'id'       => 'archive_comments_on',
            'title'    => esc_html__('Comments', 'medcaline'),
            'subtitle' => esc_html__('Show comments count on each post.', 'medcaline'),
            'type'     => 'switch',
            'default'  => true,
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Single Post', 'medcaline'),
    'icon'       => 'el-icon-file-edit',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'post_bg_color',
            'type'        => 'color',
            'title'       => esc_html__('Content Background Color', 'medcaline'),
            'transparent' => false,
            'default'     => '',
            'required' => array( 0 => 'single_post_layout', 1 => 'equals', 2 => 'real-estate' ),
            'force_output' => true
        ),
        array(
            'id'       => 'post_sidebar_pos',
            'type'     => 'button_set',
            'title'    => esc_html__('Sidebar Position', 'medcaline'),
            'subtitle' => esc_html__('Select a sidebar position', 'medcaline'),
            'options'  => array(
                'left'  => esc_html__('Left', 'medcaline'),
                'right' => esc_html__('Right', 'medcaline'),
                'none'  => esc_html__('Disabled', 'medcaline')
            ),
            'default'  => 'right'
        ),
        array(
            'id'       => 'post_author_on',
            'title'    => esc_html__('Author', 'medcaline'),
            'subtitle' => esc_html__('Show author name on single post.', 'medcaline'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_date_on',
            'title'    => esc_html__('Date', 'medcaline'),
            'subtitle' => esc_html__('Show date on single post.', 'medcaline'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_categories_on',
            'title'    => esc_html__('Categories', 'medcaline'),
            'subtitle' => esc_html__('Show category names on single post.', 'medcaline'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_tags_on',
            'title'    => esc_html__('Tags', 'medcaline'),
            'subtitle' => esc_html__('Show tag names on single post.', 'medcaline'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_comments_on',
            'title'    => esc_html__('Comments', 'medcaline'),
            'subtitle' => esc_html__('Show comments count on single post.', 'medcaline'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_comments_form_on',
            'title'    => esc_html__('Comments Form', 'medcaline'),
            'subtitle' => esc_html__('Show comments form on single post.', 'medcaline'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_social_share_on',
            'title'    => esc_html__('Social Share', 'medcaline'),
            'subtitle' => esc_html__('Show social share on single post.', 'medcaline'),
            'type'     => 'switch',
            'default'  => false,
        ),
    )
));
Redux::setSection($opt_name, array(
    'title' => esc_html__('Single Slug', 'medcaline'),
    'desc' => esc_html__('The slug name cannot be the same as a page name. Make sure to regenertate permalinks, after making changes.', 'medcaline'),
    'icon' => 'el-icon-file-edit',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'case_study_slug',
            'type' => 'text',
            'title' => esc_html__('Case Study Slug', 'medcaline'),
            'default' => '',
        ),
        array(
            'id' => 'service_slug',
            'type' => 'text',
            'title' => esc_html__('Service Slug', 'medcaline'),
            'default' => '',
        ),
        array(
            'id' => 'lq_team_slug',
            'type' => 'text',
            'title' => esc_html__('Psychologist Slug', 'medcaline'),
            'default' => '',
        ),
    )
));

/*--------------------------------------------------------------
# Shop
--------------------------------------------------------------*/
if(class_exists('Woocommerce')) {
    Redux::setSection($opt_name, array(
        'title'  => esc_html__('Shop', 'medcaline'),
        'icon'   => 'el el-shopping-cart',
        'fields' => array(
            array(
                'id'       => 'sidebar_shop',
                'type'     => 'button_set',
                'title'    => esc_html__('Sidebar Position', 'medcaline'),
                'subtitle' => esc_html__('Select a sidebar position for archive shop.', 'medcaline'),
                'options'  => array(
                    'left'  => esc_html__('Left', 'medcaline'),
                    'right' => esc_html__('Right', 'medcaline'),
                    'none'  => esc_html__('Disabled', 'medcaline')
                ),
                'default'  => 'right'
            ),
            array(
                'title' => esc_html__('Products displayed per page', 'medcaline'),
                'id' => 'product_per_page',
                'type' => 'slider',
                'subtitle' => esc_html__('Number product to show', 'medcaline'),
                'default' => 6,
                'min'  => 3,
                'step' => 1,
                'max' => 50,
                'display_value' => 'text'
            ),
            array(
                'id' => 'product_per_row',
                'type' => 'button_set',
                'title' => esc_html__('Product per row', 'medcaline'),
                'options' => array(
                    '2' => esc_html__('2 Column', 'medcaline'),
                    '3' => esc_html__('3 Column', 'medcaline'),
                    '4' => esc_html__('4 Column', 'medcaline'),
                ),
                'default' => '3',
                'force_output' => true
            ),
            array(
                'id' => 'shop_content_padding',
                'type' => 'spacing',
                'title' => esc_html__('Content Paddings', 'medcaline'),
                'subtitle' => esc_html__('Content paddings.', 'medcaline'),
                'mode' => 'padding',
                'units' => array('em', 'px', '%'),
                'top' => true,
                'right' => false,
                'bottom' => true,
                'left' => false,
                'output' => array('.woocommerce #content, .woocommerce-page #content'),
                'default' => array(
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                    'units' => 'px',
                )
            )
        )
    ));
}

/*--------------------------------------------------------------
# Footer
--------------------------------------------------------------*/
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Footer', 'medcaline'),
    'icon'   => 'el el-website',
    'fields' => array(
        array(
            'id'       => 'footer_layout',
            'type'     => 'button_set',
            'title'    => esc_html__('Layout', 'medcaline'),
            'subtitle' => esc_html__('Select a layout for upper footer area.', 'medcaline'),
            'options'  => array(
                'custom'  => esc_html__('Custom', 'medcaline'),
                '0'  => esc_html__('No Footer', 'medcaline'),
            ),
            'default'  => 'custom'
        ),
        array(
            'id'          => 'footer_layout_custom',
            'type'        => 'select',
            'title'       => esc_html__('Custom Layout', 'medcaline'),
            'desc'        => sprintf(esc_html__('To use this Option please %sClick Here%s to add your custom footer layout first.','medcaline'),'<a href="' . esc_url( admin_url( 'edit.php?post_type=footer' ) ) . '">','</a>'),
            'options'     => medcaline_list_post('footer'),
            'default'     => '',
            'required' => array( 0 => 'footer_layout', 1 => 'equals', 2 => 'custom' ),
            'force_output' => true
        ),
        array(
            'id' => 'back_totop_on',
            'type' => 'switch',
            'title' => esc_html__('Back to Top Button', 'medcaline'),
            'subtitle' => esc_html__('Show back to top button when scrolled down.', 'medcaline'),
            'default' => true
        ),
    )
));

/*--------------------------------------------------------------
# Colors
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Colors', 'medcaline'),
    'icon'   => 'el-icon-file-edit',
    'fields' => array(
        array(
            'id'          => 'primary_color',
            'type'        => 'color',
            'title'       => esc_html__('Primary Color', 'medcaline'),
            'transparent' => false,
            'default'     => '#e2ab7f'
        ),
        array(
            'id' => 'secondary_color',
            'type' => 'color',
            'title' => esc_html__('Secondary Color', 'medcaline'),
            'transparent' => false,
            'default' => '#222222'
        ),
        array(
            'id' => 'tertiary_color',
            'type' => 'color',
            'title' => esc_html__('Tertiary Color', 'medcaline'),
            'transparent' => false,
            'default' => '#6d4321'
        ),
        array(
            'id'      => 'link_color',
            'type'    => 'link_color',
            'title'   => esc_html__('Link Colors', 'medcaline'),
            'default' => array(
                'regular' => '#777777',
                'hover'   => '#e2ab7f',
                'active'  => '#e2ab7f'
            ),
            'output'  => array('a')
        )
    )
));

/*--------------------------------------------------------------
# Typography
--------------------------------------------------------------*/
$custom_font_selectors_1 = Redux::getOption($opt_name, 'custom_font_selectors_1');
$custom_font_selectors_1 = !empty($custom_font_selectors_1) ? explode(',', $custom_font_selectors_1) : array();
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Typography', 'medcaline'),
    'icon'   => 'el-icon-text-width',
    'fields' => array(
        array(
            'id'       => 'body_default_font',
            'type'     => 'select',
            'title'    => esc_html__('Body Default Font', 'medcaline'),
            'options'  => array(
                'Default'  => esc_html__('Default', 'medcaline'),
                'Google-Font'  => esc_html__('Google Font', 'medcaline'), // Export to index file or id selector, get higher priority.
            ),
            'default'  => 'Default',
        ),
        array(
            'id'          => 'font_main',
            'type'        => 'typography',
            'title'       => esc_html__('Body Google Font', 'medcaline'),
            'subtitle'    => esc_html__('This will be the default font of your website.', 'medcaline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'line-height'  => true,
            'font-size'  => true,
            'text-align'  => false,
            'output'      => array('body'),
            'units'       => 'px',
            'required' => array( 0 => 'body_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'       => 'heading_default_font',
            'type'     => 'select',
            'title'    => esc_html__('Heading Default Font', 'medcaline'),
            'options'  => array(
                'Default'  => esc_html__('Default', 'medcaline'),
                'Google-Font'  => esc_html__('Google Font', 'medcaline'), // Export to index file or id selector, get higher priority.
            ),
            'default'  => 'Default',
        ),
        array(
            'id'          => 'font_h1',
            'type'        => 'typography',
            'title'       => esc_html__('H1', 'medcaline'),
            'subtitle'    => esc_html__('This will be the default font for all H1 tags of your website.', 'medcaline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('#page.site h1', '#page.site .h1', '#page.site .text-heading'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'          => 'font_h2',
            'type'        => 'typography',
            'title'       => esc_html__('H2', 'medcaline'),
            'subtitle'    => esc_html__('This will be the default font for all H2 tags of your website.', 'medcaline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('#page.site h2', '#page.site .h2'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'          => 'font_h3',
            'type'        => 'typography',
            'title'       => esc_html__('H3', 'medcaline'),
            'subtitle'    => esc_html__('This will be the default font for all H3 tags of your website.', 'medcaline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('#page.site h3', '#page.site .h3'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'          => 'font_h4',
            'type'        => 'typography',
            'title'       => esc_html__('H4', 'medcaline'),
            'subtitle'    => esc_html__('This will be the default font for all H4 tags of your website.', 'medcaline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('#page.site h4', '#page.site .h4'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'          => 'font_h5',
            'type'        => 'typography',
            'title'       => esc_html__('H5', 'medcaline'),
            'subtitle'    => esc_html__('This will be the default font for all H5 tags of your website.', 'medcaline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('#page.site h5', '#page.site .h5'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'          => 'font_h6',
            'type'        => 'typography',
            'title'       => esc_html__('H6', 'medcaline'),
            'subtitle'    => esc_html__('This will be the default font for all H6 tags of your website.', 'medcaline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('#page.site h6', '#page.site .h6'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Fonts Selectors', 'medcaline'),
    'icon'       => 'el el-fontsize',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'custom_font_1',
            'type'        => 'typography',
            'title'       => esc_html__('Custom Font', 'medcaline'),
            'subtitle'    => esc_html__('This will be the font that applies to the class selector.', 'medcaline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => $custom_font_selectors_1,
            'units'       => 'px',

        ),
        array(
            'id'       => 'custom_font_selectors_1',
            'type'     => 'textarea',
            'title'    => esc_html__('CSS Selectors', 'medcaline'),
            'subtitle' => esc_html__('Add class selectors to apply above font.', 'medcaline'),
            'validate' => 'no_html'
        )
    )
));

/* Google Maps /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Google Maps', 'medcaline'),
    'icon'   => 'el el-map-marker',
    'fields' => array(
        array(
            'id'       => 'gm_api_key',
            'type'     => 'text',
            'title'    => esc_html__('API Key', 'medcaline'),
            'default' => 'AIzaSyC08_qdlXXCWiFNVj02d-L2BDK5qr6ZnfM',
            'desc' => esc_html__('Register a Google Maps Api key then put it in here.', 'medcaline')
        ),
    ),
));

/* 404 Page /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('404 Page', 'medcaline'),
    'icon'   => 'el-cog-alt el',
    'fields' => array(
        array(
            'id'       => 'image_404',
            'type'     => 'media',
            'title'    => esc_html__('Icon', 'medcaline'),
        ),
        array(
            'id'       => 'subtitle_404',
            'type'     => 'text',
            'title'    => esc_html__('Subtitle', 'medcaline'),
            'default' => '',
            'desc' => esc_html__('Default: OOPS! PAGE NOT FOUND!', 'medcaline')
        ),
        array(
            'id'       => 'content_404_page',
            'type'     => 'textarea',
            'title'    => esc_html__('Content', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'       => 'btn_text_404_page',
            'type'     => 'text',
            'title'    => esc_html__('Button Text', 'medcaline'),
            'default' => '',
            'desc' => esc_html__('Default: Back To HomePage', 'medcaline')
        ),
    ),
));

/* Social Media */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Social Media', 'medcaline'),
    'icon' => 'el el-twitter',
    'subsection' => false,
    'fields' => array(
        array(
            'id' => 'social_media',
            'type' => 'sorter',
            'title' => 'Enable and Sort',
            'desc' => 'Choose which social networks are displayed and edit where they link to.',
            'options' => array(
                'enabled' => array(
                    'facebook' => 'Facebook',
                    'instagram' => 'Instagram',
                    'twitter' => 'Twitter',
                ),
                'disabled' => array(
                    'tripadvisor' => 'Tripadvisor',
                    'google' => 'Google',
                    'youtube' => 'Youtube',
                    'vimeo' => 'Vimeo',
                    'tumblr' => 'Tumblr',
                    'pinterest' => 'Pinterest',
                    'yelp' => 'Yelp',
                    'skype' => 'Skype',
                    'linkedin' => 'Linkedin',
                    'rss' => 'Rss',
                )
            ),
        ),
        array(
            'id'      => 'social_facebook_url',
            'type'    => 'text',
            'title'   => esc_html__('Facebook URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_twitter_url',
            'type'    => 'text',
            'title'   => esc_html__('Twitter URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_inkedin_url',
            'type'    => 'text',
            'title'   => esc_html__('Inkedin URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_rss_url',
            'type'    => 'text',
            'title'   => esc_html__('Rss URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_instagram_url',
            'type'    => 'text',
            'title'   => esc_html__('Instagram URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_google_url',
            'type'    => 'text',
            'title'   => esc_html__('Google URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_skype_url',
            'type'    => 'text',
            'title'   => esc_html__('Skype URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_pinterest_url',
            'type'    => 'text',
            'title'   => esc_html__('Pinterest URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_vimeo_url',
            'type'    => 'text',
            'title'   => esc_html__('Vimeo URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_youtube_url',
            'type'    => 'text',
            'title'   => esc_html__('Youtube URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_yelp_url',
            'type'    => 'text',
            'title'   => esc_html__('Yelp URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_tumblr_url',
            'type'    => 'text',
            'title'   => esc_html__('Tumblr URL', 'medcaline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_tripadvisor_url',
            'type'    => 'text',
            'title'   => esc_html__('Tripadvisor URL', 'medcaline'),
            'default' => '',
        ),
    )
));

/* Custom Code /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Custom Code', 'medcaline'),
    'icon'   => 'el-icon-edit',
    'fields' => array(

        array(
            'id'       => 'site_header_code',
            'type'     => 'textarea',
            'theme'    => 'chrome',
            'title'    => esc_html__('Header Custom Codes', 'medcaline'),
            'subtitle' => esc_html__('It will insert the code to wp_head hook.', 'medcaline'),
        ),
        array(
            'id'       => 'site_footer_code',
            'type'     => 'textarea',
            'theme'    => 'chrome',
            'title'    => esc_html__('Footer Custom Codes', 'medcaline'),
            'subtitle' => esc_html__('It will insert the code to wp_footer hook.', 'medcaline'),
        ),

    ),
));

/* Custom CSS /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Custom CSS', 'medcaline'),
    'icon'   => 'el-icon-adjust-alt',
    'fields' => array(

        array(
            'id'   => 'customcss',
            'type' => 'info',
            'desc' => esc_html__('Custom CSS', 'medcaline')
        ),

        array(
            'id'       => 'site_css',
            'type'     => 'ace_editor',
            'title'    => esc_html__('CSS Code', 'medcaline'),
            'subtitle' => esc_html__('Advanced CSS Options. You can paste your custom CSS Code here.', 'medcaline'),
            'mode'     => 'css',
            'validate' => 'css',
            'theme'    => 'chrome',
            'default'  => ""
        ),

    ),
));