<?php
/**
 * Template part for displaying posts in loop
 *
 * @package Medcaline
 */

$post_social_share_on = medcaline_get_opt( 'post_social_share_on', false );
?>
<article id="post-<?php the_ID(); ?>" <?php post_class('single-hentry archive'); ?>>
    <?php
    if (has_post_format('quote')) :
        $quote_text = get_post_meta( get_the_ID(), 'featured-quote-text', true );
        $quote_cite = get_post_meta( get_the_ID(), 'featured-quote-cite', true );
        $background_img_url = "";
        if (has_post_thumbnail()) {
            $background_img_url = get_the_post_thumbnail_url(null, 'large' );
        }
        ?>
        <div class="entry-featured">
            <div class="gradient-wrap">
                <div class="gradient-background bg-image" style="background-image: url('<?php echo esc_url($background_img_url)?>');">

                </div>
                <div class="gradient-content">
                    <div class="quote-inner">
                        <div class="quote-icon bg-image"></div>
                        <a class="quote-text" href="<?php echo esc_url( get_permalink()); ?>"><?php echo esc_html($quote_text);?></a>
                        <p class="quote-cite">
                            <?php echo esc_html($quote_cite);?>
                        </p>
                    </div>
                </div>
            </div>
        </div>
    <?php elseif (has_post_format('link')) :
        $link_url = get_post_meta( get_the_ID(), 'featured-link-url', true );
        $link_text = get_post_meta( get_the_ID(), 'featured-link-text', true );
        $link_text_short = get_post_meta( get_the_ID(), 'featured-link-short', true );
        $background_img_url = "";
        if (has_post_thumbnail()) {
        $background_img_url = get_the_post_thumbnail_url(null, 'large' );
        }
        ?>
        <div class="entry-featured">
            <div class="gradient-wrap">
                <div class="gradient-background bg-image" style="background-image: url('<?php echo esc_url($background_img_url)?>');">

                </div>
                <div class="gradient-content">
                    <div class="link-inner">
                        <div class="link-icon"><i class="fas fa-link"></i></div>
                        <a class="link-text" href="<?php echo esc_url( $link_url); ?>"><?php echo esc_html($link_text);?></a>
                        <div class="link-short">
                            <a href="<?php echo esc_url( $link_url); ?>"><?php echo esc_html($link_text_short);?></a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    <?php elseif (has_post_format('video')) :
        $featured_video = get_post_meta( get_the_ID(), 'featured-video-url', true );
        ?>
        <div class="entry-featured">
            <?php
            if (has_post_thumbnail()) {
                ?>
                <div class="post-image <?php if (empty($featured_video)){ echo esc_attr('scale-hover');}?>">
                    <a href="<?php echo esc_url( get_permalink()); ?>"><?php the_post_thumbnail('large'); ?></a>
                </div>
                <?php
            }
            if (!empty($featured_video)){
                ?>
                <div class="cms-video-popup">
                    <div class="content-inner">
                        <a class="video-play-button video-default" href="<?php echo esc_url($featured_video); ?>">
                            <i class="zmdi zmdi-play"></i>
                        </a>
                    </div>
                </div>
                <?php
            }
            ?>
        </div>
    <?php elseif (has_post_format('audio')) :
        $audio_url = get_post_meta( get_the_ID(), 'featured-audio-url', true );
        ?>
        <div class="entry-featured">
            <?php
            if (!empty($audio_url)) {
                global $wp_embed;
                lcb_print_html($wp_embed->run_shortcode('[embed]' . $audio_url . '[/embed]'));
            }
            ?>
        </div>
    <?php else :
        if (has_post_thumbnail()) {
            ?>
            <div class="entry-featured">
                <div class="post-image scale-hover">
                    <a href="<?php echo esc_url( get_permalink()); ?>"><?php the_post_thumbnail('large'); ?></a>
                </div>
            </div>
            <?php
        } ?>
    <?php endif; ?>
    <div class="entry-body">
        <div class="entry-holder">
            <h2 class="entry-title">
                <a href="<?php echo esc_url( get_permalink()); ?>">
                    <?php if(is_sticky()) { ?>
                        <i class="fa fa-thumb-tack"></i>
                    <?php } ?>
                    <?php the_title(); ?>
                </a>
            </h2>
            <?php medcaline_archive_meta(); ?>
        </div>
        <div class="entry-content">
            <?php
                medcaline_entry_excerpt(50);
                wp_link_pages( array(
                    'before'      => '<div class="page-links">',
                    'after'       => '</div>',
                    'link_before' => '<span>',
                    'link_after'  => '</span>',
                ) );
            ?>
        </div>
        <div class="content-bottom">
            <div class="entry-readmore">
                <a class="btn" href="<?php echo esc_url( get_permalink()); ?>"><?php echo esc_html__('Continue Reading', 'medcaline'); ?> <i class="zmdi zmdi-chevron-right"></i></a>
            </div>
            <?php if($post_social_share_on) {
                ?>
                <div class="entry-social-share">
                    <?php medcaline_socials_share_default(get_the_ID()); ?>
                </div>
                <?php
            } ?>
        </div>
    </div>
</article><!-- #post -->