<?php
/**
 * Template part for displaying default header layout
 */

$sticky_on = medcaline_get_opt( 'sticky_on', false );
$search_on = medcaline_get_opt( 'search_on', false );
$h_btn_on = medcaline_get_opt( 'h_btn_on', 'hide' );
$h_btn_text = medcaline_get_opt( 'h_btn_text' );
$h_btn_link_type = medcaline_get_opt( 'h_btn_link_type', 'page' );
$h_btn_link = medcaline_get_opt( 'h_btn_link' );
$h_btn_link_custom = medcaline_get_opt( 'h_btn_link_custom' );
$h_btn_target = medcaline_get_opt( 'h_btn_target', '_self' );
if($h_btn_link_type == 'page') {
    $h_btn_url = get_permalink($h_btn_link);
} else {
    $h_btn_url = $h_btn_link_custom;
}

$ct_phone_label = medcaline_get_opt('ct_phone_label', "");
$ct_phone = medcaline_get_opt('ct_phone', "");
$ct_phone_href = str_replace(array('(', ')',' ','.','-','+'), '', $ct_phone);

$ct_email = medcaline_get_opt('ct_email', "");
$time_open = medcaline_get_opt('time_open', "");

$ct_address_label = medcaline_get_opt('ct_address_label', "");
$ct_address = medcaline_get_opt('ct_address', "");

$logo_light_url = get_template_directory_uri().'/assets/images/logo-light.png';
$logo_light = medcaline_get_opt( 'logo_light', array( 'url' => '', 'id' => '' ) );
if (!empty($logo_light)){
    $logo_light_url = $logo_light['url'];
}

?>
<header id="masthead" class="site-header">
    <div id="site-header-wrap" class="header-layout1 fixed-height <?php if($sticky_on == 1) { echo 'is-sticky'; } ?>">
        <div id="site-header" class="site-header-main">
            <div class="container">
                <div class="row">
                    <div class="col-lg-12 col-md-12 col-sm-12">
                        <div class="site-header-main-inner">
                            <div class="header-main-above <?php if (!has_nav_menu( 'primary' )){ echo esc_attr('menu-not-set');} ?>">
                                <div class="site-branding">
                                    <?php get_template_part( 'template-parts/header-branding' ); ?>
                                </div>
                                <?php if ( !empty($ct_phone) || !empty($ct_email) || !empty($time_open) || !empty($ct_address) ) {?>
                                    <div class="site-contact font-smooth">
                                        <?php
                                        if(!empty($ct_phone)): ?>
                                            <div class="ct-item ct-phone">
                                                <span><i class="fas fa-phone"></i></span>
                                                <div class="ct-item-text">
                                                    <a href="tel:<?php echo esc_attr( $ct_phone_href ); ?>"><?php echo esc_html( $ct_phone ); ?></a>
                                                    <p class="label"><?php echo esc_html( $ct_phone_label ); ?></p>
                                                </div>
                                            </div>
                                        <?php endif;
                                        if(!empty($ct_email) || !empty($time_open)): ?>
                                            <div class="ct-item ct-email">
                                                <span><i class="fas fac-clock"></i></span>
                                                <div class="ct-item-text">
                                                    <a href="mailto:<?php echo esc_attr( $ct_email ); ?>"><?php echo wp_kses_post( $ct_email  ); ?></a>
                                                    <p class="label"><?php echo esc_html( $time_open ); ?></p>
                                                </div>
                                            </div>
                                        <?php endif;
                                        if(!empty($ct_address)): ?>
                                            <div class="ct-item ct-address">
                                                <span><i class="fas fac-map-marker-alt"></i></span>
                                                <div class="ct-item-text">
                                                    <p class="above"><?php echo esc_html($ct_address_label); ?></p>
                                                    <p class="label"><?php echo esc_html($ct_address); ?></p>
                                                </div>
                                            </div>
                                        <?php endif;
                                        ?>
                                    </div>
                                <?php } ?>
                            </div>
                            <div class="site-navigation">
                                <div class="site-navigation-inner">
                                    <div class="site-navigation-main-content">
                                        <div class="sticky-logo">
                                            <?php
                                            if ($logo_light_url)
                                            {
                                                printf(
                                                    '<a class="logo-light" href="%1$s" title="%2$s" rel="home"><img src="%3$s" alt="%2$s"/></a>',
                                                    esc_url( home_url( '/' ) ),
                                                    esc_attr( get_bloginfo( 'name' ) ),
                                                    esc_url( $logo_light_url )
                                                );
                                            }
                                            ?>
                                        </div>
                                        <nav class="main-navigation">
                                            <?php get_template_part( 'template-parts/header-menu' ); ?>
                                        </nav>
                                        <div class="site-menu-right">
                                            <?php if($h_btn_on == 'show' && !empty($h_btn_text)) : ?>
                                                <div class="site-menu-right-button">
                                                    <?php
                                                    switch ( $h_btn_link_type ) {
                                                        case 'contact_form': ?>
                                                            <a href="#" target="<?php echo esc_attr($h_btn_target); ?>" class="popup-contact-button menu-right-item btn">
                                                                <?php echo wp_kses_post( $h_btn_text ); ?>
                                                            </a>
                                                            <?php break;
                                                        default: ?>
                                                            <a href="<?php echo esc_url( $h_btn_url ); ?>" target="<?php echo esc_attr($h_btn_target); ?>" class="menu-right-item btn">
                                                                <?php echo wp_kses_post( $h_btn_text ); ?>
                                                            </a>
                                                            <?php break;
                                                    }
                                                    ?>
                                                </div>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div id="main-menu-mobile">
                                <span class="btn-nav-mobile open-menu">
                                    <span></span>
                                </span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

        </div>
    </div>
</header>